@@ -1,42 +1,8 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  * 
- * ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is the mozilla.org LDAP XPCOM SDK.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2000
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Leif Hedstrom <leif@netscape.com>
- *   Jeremy Laine <jeremy.laine@m4x.org>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "nsLDAPInternal.h"
 #include "nsLDAPService.h"
@@ -65,8 +31,8 @@ static NS_DEFINE_CID(kLDAPOperationCID, NS_LDAPOPERATION_CID);
 //
 nsLDAPServiceEntry::nsLDAPServiceEntry()
     : mLeases(0),
-      mDelete(PR_FALSE),
-      mRebinding(PR_FALSE)
+      mDelete(false),
+      mRebinding(false)
 
 {
     mTimestamp = LL_Zero();
@@ -76,7 +42,7 @@ nsLDAPServiceEntry::nsLDAPServiceEntry()
 //
 bool nsLDAPServiceEntry::Init()
 {
-    return PR_TRUE;
+    return true;
 }
 
 // Set/Get the timestamp when this server was last used. We might have
@@ -102,11 +68,11 @@ void nsLDAPServiceEntry::IncrementLeases()
 bool nsLDAPServiceEntry::DecrementLeases()
 {
     if (!mLeases) {
-        return PR_FALSE;
+        return false;
     }
     mLeases--;
 
-    return PR_TRUE;
+    return true;
 }
 PRUint32 nsLDAPServiceEntry::GetLeases()
 {
@@ -125,11 +91,11 @@ already_AddRefed<nsILDAPServer> nsLDAPServiceEntry::GetServer()
 bool nsLDAPServiceEntry::SetServer(nsILDAPServer *aServer)
 {
     if (!aServer) {
-        return PR_FALSE;
+        return false;
     }
     mServer = aServer;
 
-    return PR_TRUE;
+    return true;
 }
 
 // Get/Set/Clear the nsLDAPConnection object for this entry.
@@ -205,9 +171,9 @@ void nsLDAPServiceEntry::SetRebinding(bool aState)
 //
 bool nsLDAPServiceEntry::DeleteEntry()
 {
-    mDelete = PR_TRUE;
+    mDelete = true;
 
-    return PR_TRUE;
+    return true;
 }
 // This is the end of the nsLDAPServiceEntry class
 
@@ -236,15 +202,8 @@ nsLDAPService::~nsLDAPService()
 //
 nsresult nsLDAPService::Init()
 {
-    if (!mServers.Init()) {
-        NS_ERROR("nsLDAPService::Init: out of memory ");
-        return NS_ERROR_OUT_OF_MEMORY;
-    }
-
-    if (!mConnections.Init()) {
-        NS_ERROR("nsLDAPService::Init: out of memory ");
-        return NS_ERROR_OUT_OF_MEMORY;
-    }
+    mServers.Init();
+    mConnections.Init();
 
     return NS_OK;
 }
@@ -511,7 +470,7 @@ NS_IMETHODIMP nsLDAPService::ReconnectConnection(const PRUnichar *aKey,
 
         // Get a new connection
         //
-        entry->SetRebinding(PR_TRUE);
+        entry->SetRebinding(true);
     }
 
     rv = EstablishConnection(entry, aListener);
@@ -524,7 +483,7 @@ NS_IMETHODIMP nsLDAPService::ReconnectConnection(const PRUnichar *aKey,
         
         if (!entry->PushListener(static_cast<nsILDAPMessageListener *>
                                             (aListener))) {
-            entry->SetRebinding(PR_FALSE);
+            entry->SetRebinding(false);
             return NS_ERROR_FAILURE;
         }
     }
@@ -598,7 +557,7 @@ nsLDAPService::OnLDAPMessage(nsILDAPMessage *aMessage)
                 return NS_ERROR_FAILURE;
             }
 
-            entry->SetRebinding(PR_FALSE);
+            entry->SetRebinding(false);
             entry->SetMessage(aMessage);
 
             // Now process all the pending callbacks/listeners. We
