@@ -1,45 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Paul Sandoz <paul.sandoz@sun.com> Sun Microsystems, Inc.
- * Portions created by the Initial Developer are Copyright (C) 2001
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Seth Spitzer <sspitzer@netscape.com>
- *   Dan Mosedale <dmose@netscape.com>
- *   Paul Sandoz <paul.sandoz@sun.com>
- *   Mark Banner <bugzilla@standard8.plus.com>
- *   Jeremy Laine <jeremy.laine@m4x.org>
- *   Simon Wilkinson <simon@sxw.org.uk>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "nsAbLDAPDirectory.h"
 
@@ -70,6 +32,7 @@
 #include "nsIMsgAccountManager.h"
 #include "nsMsgBaseCID.h"
 #include "nsMsgUtils.h"
+#include "mozilla/Services.h"
 
 #define kDefaultMaxHits 100
 
@@ -77,7 +40,7 @@ using namespace mozilla;
 
 nsAbLDAPDirectory::nsAbLDAPDirectory() :
   nsAbDirProperty(),
-  mPerformingQuery(PR_FALSE),
+  mPerformingQuery(false),
   mContext(0),
   mLock("nsAbLDAPDirectory.mLock")
 {
@@ -146,9 +109,10 @@ NS_IMETHODIMP nsAbLDAPDirectory::GetChildCards(nsISimpleEnumerator** result)
     nsresult rv;
     
     // when offline, we need to get the child cards for the local, replicated mdb directory 
-    PRBool offline;
-    nsCOMPtr <nsIIOService> ioService = do_GetService(NS_IOSERVICE_CONTRACTID, &rv);
-    NS_ENSURE_SUCCESS(rv,rv);
+    bool offline;
+    nsCOMPtr <nsIIOService> ioService =
+      mozilla::services::GetIOService();
+    NS_ENSURE_TRUE(ioService, NS_ERROR_UNEXPECTED);
     rv = ioService->GetOffline(&offline);
     NS_ENSURE_SUCCESS(rv,rv);
     
@@ -193,14 +157,14 @@ NS_IMETHODIMP nsAbLDAPDirectory::GetChildCards(nsISimpleEnumerator** result)
     return rv;
 }
 
-NS_IMETHODIMP nsAbLDAPDirectory::GetIsQuery(PRBool *aResult)
+NS_IMETHODIMP nsAbLDAPDirectory::GetIsQuery(bool *aResult)
 {
   NS_ENSURE_ARG_POINTER(aResult);
   *aResult = mIsQueryURI;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAbLDAPDirectory::HasCard(nsIAbCard* card, PRBool* hasCard)
+NS_IMETHODIMP nsAbLDAPDirectory::HasCard(nsIAbCard* card, bool* hasCard)
 {
   nsresult rv = Initiate ();
   NS_ENSURE_SUCCESS(rv, rv);
@@ -249,8 +213,9 @@ NS_IMETHODIMP nsAbLDAPDirectory::GetLDAPURL(nsILDAPURL** aResult)
       URI.Replace(0, kLDAPDirectoryRootLen, NS_LITERAL_CSTRING("ldap://"));
   }
 
-  nsCOMPtr<nsIIOService> ioService(do_GetService(NS_IOSERVICE_CONTRACTID, &rv));
-  NS_ENSURE_SUCCESS(rv, rv);
+  nsCOMPtr<nsIIOService> ioService =
+    mozilla::services::GetIOService();
+  NS_ENSURE_TRUE(ioService, NS_ERROR_UNEXPECTED);
 
   nsCOMPtr<nsIURI> result;
   rv = ioService->NewURI(URI, nsnull, nsnull, getter_AddRefs(result));
@@ -280,7 +245,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::SetLDAPURL(nsILDAPURL *aUrl)
   // listeners get updated correctly.
 
   // See if they both start with ldaps: or ldap:
-  PRBool newIsNotSecure = StringHead(tempLDAPURL, 5).Equals("ldap:");
+  bool newIsNotSecure = StringHead(tempLDAPURL, 5).Equals("ldap:");
 
   if (oldUrl.IsEmpty() ||
       StringHead(oldUrl, 5).Equals("ldap:") != newIsNotSecure)
@@ -320,14 +285,14 @@ NS_IMETHODIMP nsAbLDAPDirectory::StartSearch ()
     NS_ENSURE_SUCCESS(rv, rv);
 
     nsCOMPtr<nsIAbBooleanExpression> expression;
-    rv = nsAbQueryStringToExpression::Convert(mQueryString.get(),
+    rv = nsAbQueryStringToExpression::Convert(mQueryString,
                                               getter_AddRefs(expression));
     NS_ENSURE_SUCCESS(rv, rv);
 
     rv = arguments->SetExpression(expression);
     NS_ENSURE_SUCCESS(rv, rv);
 
-    rv = arguments->SetQuerySubDirectories(PR_TRUE);
+    rv = arguments->SetQuerySubDirectories(true);
     NS_ENSURE_SUCCESS(rv, rv);
 
     // Get the max hits to return
@@ -361,7 +326,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::StartSearch ()
 
     // Enter lock
     MutexAutoLock lock(mLock);
-    mPerformingQuery = PR_TRUE;
+    mPerformingQuery = true;
     mCache.Clear();
 
     return rv;
@@ -377,7 +342,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::StopSearch ()
     MutexAutoLock lockGuard(mLock);
     if (!mPerformingQuery)
       return NS_OK;
-    mPerformingQuery = PR_FALSE;
+    mPerformingQuery = false;
   }
   // Exit lock
 
@@ -398,7 +363,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::OnSearchFinished(PRInt32 aResult, const nsAStri
   NS_ENSURE_SUCCESS(rv, rv);
 
   MutexAutoLock lock(mLock);
-  mPerformingQuery = PR_FALSE;
+  mPerformingQuery = false;
 
   return NS_OK;
 }
@@ -422,51 +387,51 @@ NS_IMETHODIMP nsAbLDAPDirectory::OnSearchFoundCard(nsIAbCard* card)
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAbLDAPDirectory::GetSupportsMailingLists(PRBool *aSupportsMailingsLists)
+NS_IMETHODIMP nsAbLDAPDirectory::GetSupportsMailingLists(bool *aSupportsMailingsLists)
 {
   NS_ENSURE_ARG_POINTER(aSupportsMailingsLists);
-  *aSupportsMailingsLists = PR_FALSE;
+  *aSupportsMailingsLists = false;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAbLDAPDirectory::GetReadOnly(PRBool *aReadOnly)
+NS_IMETHODIMP nsAbLDAPDirectory::GetReadOnly(bool *aReadOnly)
 {
   NS_ENSURE_ARG_POINTER(aReadOnly);
 
-  *aReadOnly = PR_TRUE;
+  *aReadOnly = true;
 
 #ifdef MOZ_EXPERIMENTAL_WRITEABLE_LDAP
-  PRBool readOnly;
-  nsresult rv = GetBoolValue("readonly", PR_FALSE, &readOnly);
+  bool readOnly;
+  nsresult rv = GetBoolValue("readonly", false, &readOnly);
   NS_ENSURE_SUCCESS(rv, rv);
 
   if (readOnly)
     return NS_OK;
 
   // when online, we'll allow writing as well
-  PRBool offline;
+  bool offline;
   nsCOMPtr <nsIIOService> ioService =
-    do_GetService(NS_IOSERVICE_CONTRACTID, &rv);
-  NS_ENSURE_SUCCESS(rv,rv);
+    mozilla::services::GetIOService();
+  NS_ENSURE_TRUE(ioService, NS_ERROR_UNEXPECTED);
 
   rv = ioService->GetOffline(&offline);
   NS_ENSURE_SUCCESS(rv,rv);
 
   if (!offline)
-    *aReadOnly = PR_FALSE;
+    *aReadOnly = false;
 #endif
 
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAbLDAPDirectory::GetIsRemote(PRBool *aIsRemote)
+NS_IMETHODIMP nsAbLDAPDirectory::GetIsRemote(bool *aIsRemote)
 {
   NS_ENSURE_ARG_POINTER(aIsRemote);
-  *aIsRemote = PR_TRUE;
+  *aIsRemote = true;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAbLDAPDirectory::GetIsSecure(PRBool *aIsSecure)
+NS_IMETHODIMP nsAbLDAPDirectory::GetIsSecure(bool *aIsSecure)
 {
   NS_ENSURE_ARG_POINTER(aIsSecure);
 
@@ -480,18 +445,18 @@ NS_IMETHODIMP nsAbLDAPDirectory::GetIsSecure(PRBool *aIsSecure)
 }
 
 NS_IMETHODIMP nsAbLDAPDirectory::UseForAutocomplete(const nsACString &aIdentityKey,
-                                                    PRBool *aResult)
+                                                    bool *aResult)
 {
   NS_ENSURE_ARG_POINTER(aResult);
 
   // Set this to false by default to make the code easier below.
-  *aResult = PR_FALSE;
+  *aResult = false;
 
   nsresult rv;
-  PRBool offline = PR_FALSE;
+  bool offline = false;
   nsCOMPtr <nsIIOService> ioService =
-    do_GetService(NS_IOSERVICE_CONTRACTID, &rv);
-  NS_ENSURE_SUCCESS(rv, rv);
+    mozilla::services::GetIOService();
+  NS_ENSURE_TRUE(ioService, NS_ERROR_UNEXPECTED);
 
   rv = ioService->GetOffline(&offline);
   NS_ENSURE_SUCCESS(rv, rv);
@@ -506,7 +471,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::UseForAutocomplete(const nsACString &aIdentityK
                                               &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
-  PRBool useDirectory = PR_FALSE;
+  bool useDirectory = false;
   rv = prefs->GetBoolPref("ldap_2.autoComplete.useDirectory", &useDirectory);
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -530,7 +495,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::UseForAutocomplete(const nsACString &aIdentityK
       rv = accountManager->GetIdentity(aIdentityKey, getter_AddRefs(identity));
       if (NS_SUCCEEDED(rv))
       {
-        PRBool overrideGlobalPref = PR_FALSE;
+        bool overrideGlobalPref = false;
         identity->GetOverrideGlobalPref(&overrideGlobalPref);
         if (overrideGlobalPref)
           identity->GetDirectoryServer(prefName);
@@ -562,7 +527,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::UseForAutocomplete(const nsACString &aIdentityK
     if (NS_FAILED(GetReplicationFile(getter_AddRefs(databaseFile))))
       return NS_OK;
 
-    PRBool exists;
+    bool exists;
     rv = databaseFile->Exists(&exists);
     NS_ENSURE_SUCCESS(rv, rv);
 
@@ -732,7 +697,7 @@ NS_IMETHODIMP nsAbLDAPDirectory::GetReplicationDatabase(nsIAddrDatabase **aResul
     do_GetService(NS_ADDRDATABASE_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  return addrDBFactory->Open(databaseFile, PR_FALSE /* no create */, PR_TRUE,
+  return addrDBFactory->Open(databaseFile, false /* no create */, true,
                            aResult);
 }
 
