@@ -1,41 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2006
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   David Bienvenu <bienvenu@mozilla.org>
- *   Karsten Düsterloh <mnyromyr@tprac.de>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #include "msgCore.h"
 #include "nsMsgTagService.h"
@@ -61,7 +27,7 @@
 #define TAG_CMP_EQUAL           0
 #define TAG_CMP_GREATER         1
 
-static PRBool gMigratingKeys = PR_FALSE;
+static bool gMigratingKeys = false;
 
 // comparison functions for nsQuickSort
 static int
@@ -292,7 +258,7 @@ NS_IMETHODIMP nsMsgTagService::AddTag(const nsAString  &tag,
   // to normalize all keys to lower case (upper case looks ugly in prefs.js)
   ToLowerCase(key);
   nsCAutoString prefName(key);
-  while (PR_TRUE)
+  while (true)
   {
     nsAutoString tagValue;
     nsresult rv = GetTagForKey(prefName, tagValue);
@@ -300,7 +266,7 @@ NS_IMETHODIMP nsMsgTagService::AddTag(const nsAString  &tag,
       return AddTagForKey(prefName, tag, color, ordinal);
     prefName.Append('A');
   }
-  NS_ASSERTION(PR_FALSE, "can't get here");
+  NS_ASSERTION(false, "can't get here");
   return NS_ERROR_FAILURE;
 }
 
@@ -507,7 +473,7 @@ nsresult nsMsgTagService::MigrateLabelsToTags()
     return rv;
   else if (prefVersion == 1)
   {
-    gMigratingKeys = PR_TRUE;
+    gMigratingKeys = true;
   // need to convert the keys to lower case
     nsIMsgTag **tagArray;
     PRUint32 numTags;
@@ -526,7 +492,7 @@ nsresult nsMsgTagService::MigrateLabelsToTags()
       AddTagForKey(key, tagStr, color, ordinal);
     }
     NS_FREE_XPCOM_ISUPPORTS_POINTER_ARRAY(numTags, tagArray);
-    gMigratingKeys = PR_FALSE;
+    gMigratingKeys = false;
   }
   else 
   {
@@ -559,7 +525,7 @@ nsresult nsMsgTagService::MigrateLabelsToTags()
   return rv;
 }
 
-NS_IMETHODIMP nsMsgTagService::IsValidKey(const nsACString &aKey, PRBool *aResult)
+NS_IMETHODIMP nsMsgTagService::IsValidKey(const nsACString &aKey, bool *aResult)
 {
   NS_ENSURE_ARG_POINTER(aResult);
   *aResult = m_keys.Contains(aKey);
