@@ -1,43 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Jean-Francois Ducarroz <ducarroz@netscape.com>
- *   Pierre Phaneuf <pp@ludusdesign.com>
- *   Seth Spitzer <sspitzer@netscape.com>
- *   Jeff Beckley <beckley@qualcomm.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #ifdef MOZ_LOGGING
 #define FORCE_PR_LOG /* Allow logging in the release build (sorry this breaks the PCH) */
@@ -71,7 +35,6 @@
 #include "nsIBaseWindow.h"
 #include "nsIPrefService.h"
 #include "nsIPrefBranch.h"
-#include "nsIPrefBranch2.h"
 #include "nsMsgBaseCID.h"
 #include "nsIMsgAccountManager.h"
 #include "nsIMimeMiscStatus.h"
@@ -88,6 +51,8 @@
 #include "nsUTF8Utils.h"
 #include "nsILineBreaker.h"
 #include "nsLWBrkCIID.h"
+#include "mozilla/Services.h"
+#include "mimemoz2.h"
 
 #ifdef MSGCOMP_TRACE_PERFORMANCE
 #include "prlog.h"
@@ -96,12 +61,6 @@
 #include "nsMsgUtils.h"
 #endif
 
-// <for functions="HTMLSantinize">
-#include "nsIParser.h"
-#include "nsParserCIID.h"
-#include "nsIContentSink.h"
-#include "mozISanitizingSerializer.h"
-
 #include "nsICommandLine.h"
 #include "nsIAppStartup.h"
 #include "nsMsgUtils.h"
@@ -112,10 +71,6 @@
 #include "nsIWidget.h"
 #endif
 
-static NS_DEFINE_CID(kParserCID, NS_PARSER_CID);
-// </for>
-
-
 #define DEFAULT_CHROME  "chrome://messenger/content/messengercompose/messengercompose.xul"
 
 #define PREF_MAIL_COMPOSE_MAXRECYCLEDWINDOWS  "mail.compose.max_recycled_windows"
@@ -155,7 +110,7 @@ nsMsgComposeService::nsMsgComposeService()
 {
 
 // Defaulting the value of mLogComposePerformance to FALSE to prevent logging.
-  mLogComposePerformance = PR_FALSE;
+  mLogComposePerformance = false;
 #ifdef MSGCOMP_TRACE_PERFORMANCE
   if (!MsgComposeLogModule)
       MsgComposeLogModule = PR_NewLogModule("msgcompose");
@@ -191,17 +146,18 @@ nsresult nsMsgComposeService::Init()
   // Register observers
 
   // Register for quit application and profile change, we will need to clear the cache.
-  nsCOMPtr<nsIObserverService> observerService = do_GetService("@mozilla.org/observer-service;1", &rv);
-  if (NS_SUCCEEDED(rv))
+  nsCOMPtr<nsIObserverService> observerService =
+    mozilla::services::GetObserverService();
+  if (observerService)
   {
-    rv = observerService->AddObserver(this, "quit-application", PR_TRUE);
-    rv = observerService->AddObserver(this, "profile-do-change", PR_TRUE);
+    rv = observerService->AddObserver(this, "quit-application", true);
+    rv = observerService->AddObserver(this, "profile-do-change", true);
   }
 
   // Register some pref observer
-  nsCOMPtr<nsIPrefBranch2> pbi = do_GetService(NS_PREFSERVICE_CONTRACTID);
+  nsCOMPtr<nsIPrefBranch> pbi = do_GetService(NS_PREFSERVICE_CONTRACTID);
   if (pbi)
-    rv = pbi->AddObserver(PREF_MAIL_COMPOSE_MAXRECYCLEDWINDOWS, this, PR_TRUE);
+    rv = pbi->AddObserver(PREF_MAIL_COMPOSE_MAXRECYCLEDWINDOWS, this, true);
 
   mOpenComposeWindows.Init();
   Reset();
@@ -259,7 +215,7 @@ nsMsgComposeService::OpenComposeWindowWithParams(const char *chrome,
 #ifdef MSGCOMP_TRACE_PERFORMANCE
   if(mLogComposePerformance)
   {
-    TimeStamp("Start opening the window", PR_TRUE);
+    TimeStamp("Start opening the window", true);
   }
 #endif
 
@@ -295,7 +251,7 @@ nsMsgComposeService::OpenComposeWindowWithParams(const char *chrome,
              clear the cache entry if everything goes well
           */
           nsCOMPtr<nsIDOMWindow> domWindow(mCachedWindows[i].window);
-          rv = ShowCachedComposeWindow(domWindow, PR_TRUE);
+          rv = ShowCachedComposeWindow(domWindow, true);
           if (NS_SUCCEEDED(rv))
           {
             mCachedWindows[i].listener->OnReopen(params);
@@ -388,14 +344,14 @@ nsMsgComposeService::DetermineComposeHTML(nsIMsgIdentity *aIdentity, MSG_Compose
 {
   NS_ENSURE_ARG_POINTER(aComposeHTML);
 
-  *aComposeHTML = PR_TRUE;
+  *aComposeHTML = true;
   switch (aFormat)
   {
     case nsIMsgCompFormat::HTML:
-      *aComposeHTML = PR_TRUE;
+      *aComposeHTML = true;
       break;
     case nsIMsgCompFormat::PlainText:
-      *aComposeHTML = PR_FALSE;
+      *aComposeHTML = false;
       break;
 
     default:
@@ -457,7 +413,7 @@ nsMsgComposeService::GetOrigWindowSelection(MSG_ComposeType type, nsIMsgWindow *
 
   nsCOMPtr<nsIDocShellTreeItem> childAsItem;
   rv = rootDocShellAsNode->FindChildWithName(NS_LITERAL_STRING("messagepane").get(),
-                                             PR_TRUE, PR_FALSE, nsnull, nsnull, getter_AddRefs(childAsItem));
+                                             true, false, nsnull, nsnull, getter_AddRefs(childAsItem));
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIDocShell> docShell(do_QueryInterface(childAsItem, &rv));
@@ -630,7 +586,7 @@ nsMsgComposeService::OpenComposeWindow(const char *msgComposeWindowURL, nsIMsgDB
         if (type != nsIMsgCompType::NewsPost) {
           char buff[256];
           sprintf(buff, "Start opening the window, message size = %d", GetMessageSizeFromURI(originalMsgURI));
-          TimeStamp(buff, PR_TRUE);
+          TimeStamp(buff, true);
         }
 #endif
       }//end if(mLogComposePerformance)
@@ -696,34 +652,14 @@ NS_IMETHODIMP nsMsgComposeService::GetParamsForMailto(nsIURI * aURI, nsIMsgCompo
       {
         //For security reason, we must sanitize the message body before accepting any html...
 
-        // Create a parser
-        nsCOMPtr<nsIParser> parser = do_CreateInstance(kParserCID);
+        rv = HTMLSanitize(rawBody, sanitizedBody); // from mimemoz2.h
 
-        // Create the appropriate output sink
-        nsCOMPtr<nsIContentSink> sink = do_CreateInstance(MOZ_SANITIZINGHTMLSERIALIZER_CONTRACTID);
-
-        nsCString allowedTags;
-        nsCOMPtr<nsIPrefBranch> prefs(do_GetService(NS_PREFSERVICE_CONTRACTID));
-        if (prefs)
-          prefs->GetCharPref(MAILNEWS_ROOT_PREF "display.html_sanitizer.allowed_tags", getter_Copies(allowedTags));
-
-        if (parser && sink)
+        if (NS_FAILED(rv))
         {
-          nsCOMPtr<mozISanitizingHTMLSerializer> sanSink(do_QueryInterface(sink));
-          if (sanSink)
-          {
-            sanSink->Initialize(&sanitizedBody, 0, NS_ConvertASCIItoUTF16(allowedTags));
-
-            parser->SetContentSink(sink);
-            rv = parser->Parse(rawBody, 0, NS_LITERAL_CSTRING("text/html"), PR_TRUE);
-            if (NS_FAILED(rv))
-            {
-              // Something went horribly wrong with parsing for html format
-              // in the body.  Set composeHTMLFormat to PR_FALSE so we show the
-              // plain text mail compose.
-              composeHTMLFormat = PR_FALSE;
-            }
-          }
+          // Something went horribly wrong with parsing for html format
+          // in the body.  Set composeHTMLFormat to false so we show the
+          // plain text mail compose.
+          composeHTMLFormat = false;
         }
       }
 
@@ -804,14 +740,13 @@ nsMsgComposeService::GetDefaultIdentity(nsIMsgIdentity **_retval)
 
   nsresult rv;
   nsCOMPtr<nsIMsgAccountManager> accountManager = do_GetService(NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
-  if (NS_SUCCEEDED(rv) && accountManager)
-  {
-    nsCOMPtr<nsIMsgAccount> defaultAccount;
-    rv = accountManager->GetDefaultAccount(getter_AddRefs(defaultAccount));
-    if (NS_SUCCEEDED(rv) && defaultAccount)
-      defaultAccount->GetDefaultIdentity(_retval);
-  }
-  return rv;
+  NS_ENSURE_SUCCESS(rv, rv);
+
+  nsCOMPtr<nsIMsgAccount> defaultAccount;
+  rv = accountManager->GetDefaultAccount(getter_AddRefs(defaultAccount));
+  NS_ENSURE_SUCCESS(rv, rv);
+
+  return defaultAccount->GetDefaultIdentity(_retval);
 }
 
 /* readonly attribute boolean logComposePerformance; */
@@ -862,11 +797,11 @@ nsMsgComposeService::IsCachedWindow(nsIDOMWindow *aCachedWindow, bool *aIsCached
   for (i = 0; i < mMaxRecycledWindows; i ++)
     if (mCachedWindows[i].window.get() == aCachedWindow)
     {
-      *aIsCachedWindow = PR_TRUE;
+      *aIsCachedWindow = true;
       return NS_OK;
     }
 
- *aIsCachedWindow = PR_FALSE;
+ *aIsCachedWindow = false;
   return NS_OK;
 }
 
@@ -886,7 +821,7 @@ nsMsgComposeService::CacheWindow(nsIDOMWindow *aWindow, bool aComposeHTML, nsIMs
   {
     if (!mCachedWindows[i].window)
     {
-      rv = ShowCachedComposeWindow(aWindow, PR_FALSE);
+      rv = ShowCachedComposeWindow(aWindow, false);
       if (NS_SUCCEEDED(rv))
         mCachedWindows[i].Initialize(aWindow, aListener, aComposeHTML);
 
@@ -914,7 +849,7 @@ nsMsgComposeService::CacheWindow(nsIDOMWindow *aWindow, bool aComposeHTML, nsIMs
     CloseHiddenCachedWindow(mCachedWindows[oppositeTypeId].window);
     mCachedWindows[oppositeTypeId].Clear();
 
-    rv = ShowCachedComposeWindow(aWindow, PR_FALSE);
+    rv = ShowCachedComposeWindow(aWindow, false);
     if (NS_SUCCEEDED(rv))
       mCachedWindows[oppositeTypeId].Initialize(aWindow, aListener, aComposeHTML);
 
@@ -951,7 +886,7 @@ NS_IMPL_ISUPPORTS3(nsMsgTemplateReplyHelper,
 
 nsMsgTemplateReplyHelper::nsMsgTemplateReplyHelper()
 {
-  mInMsgBody = PR_FALSE;
+  mInMsgBody = false;
   memset(mLastBlockChars, 0, sizeof(mLastBlockChars));
 }
 
@@ -989,7 +924,7 @@ NS_IMETHODIMP nsMsgTemplateReplyHelper::OnStopRunningUrl(nsIURI *aUrl, nsresult
 
   rv = accountManager->FindAccountForServer(mServer, getter_AddRefs(account));
   NS_ENSURE_SUCCESS(rv, rv);
-  account->GetDefaultIdentity(getter_AddRefs(identity));
+  rv = account->GetDefaultIdentity(getter_AddRefs(identity));
   NS_ENSURE_SUCCESS(rv, rv);
 
   // create the compose params object
@@ -1178,7 +1113,7 @@ NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(nsIMsgDBHdr *aMsgHdr, const
   {
     // ### probably want to return a specific error and
     // have the calling code disable the filter.
-    NS_ASSERTION(PR_FALSE, "failed to get msg hdr");
+    NS_ASSERTION(false, "failed to get msg hdr");
     return NS_ERROR_FAILURE;
   }
   // we need to convert the template uri, which is of the form
@@ -1192,8 +1127,8 @@ NS_IMETHODIMP nsMsgComposeService::ReplyWithTemplate(nsIMsgDBHdr *aMsgHdr, const
 
   rv = msgService->StreamMessage(templateMsgHdrUri.get(), listenerSupports,
                                  aMsgWindow, helper,
-                                 PR_FALSE, // convert data
-                                 EmptyCString(), PR_FALSE, nsnull);
+                                 false, // convert data
+                                 EmptyCString(), false, nsnull);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIMsgFolder> folder;
@@ -1231,12 +1166,12 @@ nsMsgComposeService::ForwardMessage(const nsAString &forwardTo,
 
   nsCOMPtr<nsIMsgFolder> folder;
   aMsgHdr->GetFolder(getter_AddRefs(folder));
-  if (!folder)
-    return NS_ERROR_NULL_POINTER;
+  NS_ENSURE_TRUE(folder, NS_ERROR_NULL_POINTER);
+
   folder->GetUriForMsg(aMsgHdr, msgUri);
 
   // get the MsgIdentity for the above key using AccountManager
-  nsCOMPtr<nsIMsgAccountManager> accountManager = 
+  nsCOMPtr<nsIMsgAccountManager> accountManager =
     do_GetService (NS_MSGACCOUNTMANAGER_CONTRACTID, &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
@@ -1246,15 +1181,20 @@ nsMsgComposeService::ForwardMessage(const nsAString &forwardTo,
   rv = accountManager->FindAccountForServer(aServer, getter_AddRefs(account));
   NS_ENSURE_SUCCESS(rv, rv);
   rv = account->GetDefaultIdentity(getter_AddRefs(identity));
-  NS_ENSURE_SUCCESS(rv, rv);
+  // Use default identity if no identity has been found on this account
+  if (NS_FAILED(rv) || !identity)
+  {
+    rv = GetDefaultIdentity(getter_AddRefs(identity));
+    NS_ENSURE_SUCCESS(rv, rv);
+  }
 
   if (aForwardType == nsIMsgComposeService::kForwardInline)
     return RunMessageThroughMimeDraft(msgUri,
                                       nsMimeOutput::nsMimeMessageDraftOrTemplate,
                                       identity,
                                       msgUri.get(), aMsgHdr,
-                                      PR_TRUE, forwardTo,
-                                      PR_FALSE, aMsgWindow);
+                                      true, forwardTo,
+                                      false, aMsgWindow);
 
   nsCOMPtr<nsIDOMWindow> parentWindow;
   if (aMsgWindow)
@@ -1279,11 +1219,11 @@ nsMsgComposeService::ForwardMessage(const nsAString &forwardTo,
   pMsgComposeParams->SetOriginalMsgURI(msgUri.get());
   // create the nsIMsgCompose object to send the object
   nsCOMPtr<nsIMsgCompose> pMsgCompose (do_CreateInstance(NS_MSGCOMPOSE_CONTRACTID, &rv));
-  NS_ENSURE_SUCCESS(rv,rv);
+  NS_ENSURE_SUCCESS(rv, rv);
 
   /** initialize nsIMsgCompose, Send the message, wait for send completion response **/
   rv = pMsgCompose->Initialize(pMsgComposeParams, parentWindow, nsnull);
-  NS_ENSURE_SUCCESS(rv,rv);
+  NS_ENSURE_SUCCESS(rv, rv);
 
   rv = pMsgCompose->SendMsg(nsIMsgSend::nsMsgDeliverNow, identity, nsnull, nsnull, nsnull);
   NS_ENSURE_SUCCESS(rv, rv);
@@ -1300,9 +1240,9 @@ nsresult nsMsgComposeService::ShowCachedComposeWindow(nsIDOMWindow *aComposeWind
 {
   nsresult rv = NS_OK;
 
-  nsCOMPtr<nsIObserverService> obs
-    (do_GetService("@mozilla.org/observer-service;1", &rv));
-  NS_ENSURE_SUCCESS(rv, rv);
+  nsCOMPtr<nsIObserverService> obs =
+    mozilla::services::GetObserverService();
+  NS_ENSURE_TRUE(obs, NS_ERROR_UNEXPECTED);
 
   nsCOMPtr <nsPIDOMWindow> window = do_QueryInterface(aComposeWindow, &rv);
 
@@ -1591,7 +1531,7 @@ nsMsgComposeService::RunMessageThroughMimeDraft(
   mimeConverter->SetForwardInline(aForwardInline);
   if (!aForwardTo.IsEmpty())
   {
-    mimeConverter->SetForwardInlineFilter(PR_TRUE);
+    mimeConverter->SetForwardInlineFilter(true);
     mimeConverter->SetForwardToAddress(aForwardTo);
   }
   mimeConverter->SetOverrideComposeFormat(aOverrideComposeFormat);
@@ -1662,7 +1602,7 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
   nsAutoString uristr;
   bool composeShouldHandle = true;
 
-  rv = aCmdLine->FindFlag(NS_LITERAL_STRING("compose"), PR_FALSE, &found);
+  rv = aCmdLine->FindFlag(NS_LITERAL_STRING("compose"), false, &found);
   NS_ENSURE_SUCCESS(rv, rv);
 
 #ifndef MOZ_SUITE
@@ -1670,10 +1610,10 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
   // instead of -compose.
   if (found == -1)
   {
-    rv = aCmdLine->FindFlag(NS_LITERAL_STRING("url"), PR_FALSE, &found);
+    rv = aCmdLine->FindFlag(NS_LITERAL_STRING("url"), false, &found);
     // we don't want to consume the argument for -url unless we're sure it is a mailto url and we'll
     // figure that out shortly.
-    composeShouldHandle = PR_FALSE;
+    composeShouldHandle = false;
   }
 #endif
 
@@ -1697,7 +1637,7 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
         StringBeginsWith(uristr, NS_LITERAL_STRING("format=")) ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("body="))  ||
         StringBeginsWith(uristr, NS_LITERAL_STRING("attachment="))) {
-      composeShouldHandle = PR_TRUE; // the -url argument looks like mailto
+      composeShouldHandle = true; // the -url argument looks like mailto
       end++;
       // mailto: URIs are frequently passed with spaces in them. They should be
       // escaped with %20, but we hack around broken clients. See bug 231032.
@@ -1731,7 +1671,7 @@ nsMsgComposeService::Handle(nsICommandLine* aCmdLine)
     wwatch->OpenWindow(nsnull, DEFAULT_CHROME, "_blank",
                        "chrome,dialog=no,all", arg, getter_AddRefs(opened));
 
-    aCmdLine->SetPreventDefault(PR_TRUE);
+    aCmdLine->SetPreventDefault(true);
   }
   return NS_OK;
 }
