@@ -1,42 +1,7 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 2002
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Patrick C. Beard <beard@netscape.com>
- *   Seth Spitzer <sspitzer@netscape.com>
- *   Kent James <kent@caspia.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #ifdef MOZ_LOGGING
 // sorry, this has to be before the pre-compiled header
@@ -77,23 +42,19 @@
 #include "nsIMsgHdr.h"
 
 // needed to strip html out of the body
-#include "nsParserCIID.h"
-#include "nsIParser.h"
-#include "nsIHTMLContentSink.h"
 #include "nsIContentSerializer.h"
 #include "nsLayoutCID.h"
-#include "nsIHTMLToTextSink.h"
+#include "nsIParserUtils.h"
 #include "nsIDocumentEncoder.h"
 
 #include "nsIncompleteGamma.h"
 #include <math.h>
 #include <prmem.h>
 #include "nsIMsgTraitService.h"
+#include "mozilla/Services.h"
 
 static PRLogModuleInfo *BayesianFilterLogModule = nsnull;
 
-static NS_DEFINE_CID(kParserCID, NS_PARSER_CID);
-
 #define kDefaultJunkThreshold .99 // we override this value via a pref
 static const char* kBayesianFilterTokenDelimiters = " \t\n\r\f.";
 static unsigned int kMinLengthForToken = 3; // lower bound on the number of characters in a word before we treat it as a token
@@ -325,7 +286,7 @@ Tokenizer::Tokenizer() :
   TokenHash(sizeof(Token)),
   mBodyDelimiters(kBayesianFilterTokenDelimiters),
   mHeaderDelimiters(kBayesianFilterTokenDelimiters),
-  mCustomHeaderTokenization(PR_FALSE),
+  mCustomHeaderTokenization(false),
   mMaxLengthForToken(kMaxLengthForToken)
 {
   nsresult rv;
@@ -344,7 +305,7 @@ Tokenizer::Tokenizer() :
    */
   rv = prefBranch->GetBoolPref("iframe_to_div", &mIframeToDiv);
   if (NS_FAILED(rv))
-    mIframeToDiv = PR_FALSE;
+    mIframeToDiv = false;
 
   /*
    * the list of delimiters used to tokenize the message and body
@@ -413,7 +374,7 @@ Tokenizer::Tokenizer() :
 
   if (NS_SUCCEEDED(rv))
   {
-    mCustomHeaderTokenization = PR_TRUE;
+    mCustomHeaderTokenization = true;
     for (PRUint32 i = 0; i < count; i++)
     {
       nsCString value;
@@ -425,7 +386,7 @@ Tokenizer::Tokenizer() :
       }
       mEnabledHeaders.AppendElement(headers[i]);
       if (value.EqualsLiteral("standard"))
-        value.SetIsVoid(PR_TRUE); // Void means use default delimiter
+        value.SetIsVoid(true); // Void means use default delimiter
       else if (value.EqualsLiteral("full"))
         value.Truncate(); // Empty means add full header
       else
@@ -468,9 +429,9 @@ static bool isDecimalNumber(const char* word)
     char c;
     while ((c = *p++)) {
         if (!isdigit((unsigned char) c))
-            return PR_FALSE;
+            return false;
     }
-    return PR_TRUE;
+    return true;
 }
 
 static bool isASCII(const char* word)
@@ -479,9 +440,9 @@ static bool isASCII(const char* word)
     unsigned char c;
     while ((c = *p++)) {
         if (c > 127)
-            return PR_FALSE;
+            return false;
     }
-    return PR_TRUE;
+    return true;
 }
 
 inline bool isUpperCase(char c) { return ('A' <= c) && (c <= 'Z'); }
@@ -573,15 +534,15 @@ void Tokenizer::tokenizeHeaders(nsIUTF8StringEnumerator * aHeaderNames, nsIUTF8S
         {
           if (mEnabledHeadersDelimiters[i].IsVoid())
             // tokenize with standard delimiters for all headers
-            addTokenForHeader(headerName.get(), headerValue, PR_TRUE);
+            addTokenForHeader(headerName.get(), headerValue, true);
           else if (mEnabledHeadersDelimiters[i].IsEmpty())
             // do not break the header into tokens
             addTokenForHeader(headerName.get(), headerValue);
           else
             // use the delimiter in mEnabledHeadersDelimiters
-            addTokenForHeader(headerName.get(), headerValue, PR_TRUE,
+            addTokenForHeader(headerName.get(), headerValue, true,
                               mEnabledHeadersDelimiters[i].get());
-          headerProcessed = PR_TRUE;
+          headerProcessed = true;
           break; // we found the header, no need to look for more custom values
         }
 
@@ -589,7 +550,7 @@ void Tokenizer::tokenizeHeaders(nsIUTF8StringEnumerator * aHeaderNames, nsIUTF8S
       {
         if (headerName.Equals(mDisabledHeaders[i]))
         {
-          headerProcessed = PR_TRUE;
+          headerProcessed = true;
           break;
         }
       }
@@ -637,7 +598,7 @@ void Tokenizer::tokenizeHeaders(nsIUTF8StringEnumerator * aHeaderNames, nsIUTF8S
         if (headerName.Equals("subject"))
         {
           // we want to tokenize the subject
-          addTokenForHeader(headerName.get(), headerValue, PR_TRUE);
+          addTokenForHeader(headerName.get(), headerValue, true);
         }
 
         // important: leave out sender field. Too strong of an indicator
@@ -761,18 +722,18 @@ static bool isJapanese(const char* word)
   // it is japanese chunk if it contains any hiragana or katakana.
   while((c = *p++))
     if( IS_JAPANESE_SPECIFIC(c))
-      return PR_TRUE;
+      return true;
 
-  return PR_FALSE;
+  return false;
 }
 
 static bool isFWNumeral(const PRUnichar* p1, const PRUnichar* p2)
 {
   for(;p1<p2;p1++)
     if(!IS_JA_FWNUMERAL(*p1))
-      return PR_FALSE;
+      return false;
 
-  return PR_TRUE;
+  return true;
 }
 
 // The japanese tokenizer was added as part of Bug #277354
@@ -807,27 +768,13 @@ void Tokenizer::tokenize_japanese_word(char* chunk)
 
 nsresult Tokenizer::stripHTML(const nsAString& inString, nsAString& outString)
 {
-  nsresult rv = NS_OK;
-  // Create a parser
-  nsCOMPtr<nsIParser> parser = do_CreateInstance(kParserCID, &rv);
-  NS_ENSURE_SUCCESS(rv, rv);
-
-  // Create the appropriate output sink
-  nsCOMPtr<nsIContentSink> sink = do_CreateInstance(NS_PLAINTEXTSINK_CONTRACTID,&rv);
-  NS_ENSURE_SUCCESS(rv, rv);
-
-  nsCOMPtr<nsIHTMLToTextSink> textSink(do_QueryInterface(sink));
-  NS_ENSURE_TRUE(textSink, NS_ERROR_FAILURE);
   PRUint32 flags = nsIDocumentEncoder::OutputLFLineBreak
                  | nsIDocumentEncoder::OutputNoScriptContent
                  | nsIDocumentEncoder::OutputNoFramesContent
                  | nsIDocumentEncoder::OutputBodyOnly;
-
-  textSink->Initialize(&outString, flags, 80);
-
-  parser->SetContentSink(sink);
-
-  return parser->Parse(inString, 0, NS_LITERAL_CSTRING("text/html"), PR_TRUE);
+  nsCOMPtr<nsIParserUtils> utils =
+    do_GetService(NS_PARSERUTILS_CONTRACTID);
+  return utils->ConvertToPlainText(inString, flags, 80, outString);
 }
 
 void Tokenizer::tokenize(const char* aText)
@@ -898,7 +845,7 @@ void Tokenizer::tokenize(const char* aText)
             PRInt32 len = uword.Length(), pos = 0, begin, end;
             bool gotUnit;
             while (pos < len) {
-                rv = mScanner->Next(utext, len, pos, PR_TRUE, &begin, &end, &gotUnit);
+                rv = mScanner->Next(utext, len, pos, true, &begin, &end, &gotUnit);
                 if (NS_SUCCEEDED(rv) && gotUnit) {
                     NS_ConvertUTF16toUTF8 utfUnit(utext + begin, end - begin);
                     add(utfUnit.get());
@@ -928,13 +875,13 @@ void Tokenizer::UnescapeCString(nsCString& aCString)
     if (!inEscape)
     {
       if (*readIter == '\\')
-        inEscape = PR_TRUE;
+        inEscape = true;
       else
         *(writeIter++) = *readIter;
     }
     else
     {
-      inEscape = PR_FALSE;
+      inEscape = false;
       switch (*readIter)
       {
         case '\\':
@@ -1027,7 +974,7 @@ const PRUint32 kBufferSize = 16384;
 TokenStreamListener::TokenStreamListener(TokenAnalyzer* analyzer)
     :   mAnalyzer(analyzer),
         mBuffer(NULL), mBufferSize(kBufferSize), mLeftOverCount(0),
-        mSetAttachmentFlag(PR_FALSE)
+        mSetAttachmentFlag(false)
 {
 }
 
@@ -1106,13 +1053,11 @@ NS_IMETHODIMP TokenStreamListener::GetProperties(nsIWritablePropertyBag2 * *aPro
 NS_IMETHODIMP TokenStreamListener::OnStartRequest(nsIRequest *aRequest, nsISupports *aContext)
 {
     mLeftOverCount = 0;
-    if (!mTokenizer)
-        return NS_ERROR_OUT_OF_MEMORY;
+    NS_ENSURE_TRUE(mTokenizer, NS_ERROR_OUT_OF_MEMORY);
     if (!mBuffer)
     {
         mBuffer = new char[mBufferSize];
-        if (!mBuffer)
-            return NS_ERROR_OUT_OF_MEMORY;
+        NS_ENSURE_TRUE(mBuffer, NS_ERROR_OUT_OF_MEMORY);
     }
 
     // get the url for the channel and set our nsIMsgHeaderSink on it so we get notified
@@ -1150,8 +1095,7 @@ NS_IMETHODIMP TokenStreamListener::OnDataAvailable(nsIRequest *aRequest, nsISupp
         if (!mBuffer)
         {
           mBuffer = new char[mBufferSize];
-          if (!mBuffer)
-            return NS_ERROR_OUT_OF_MEMORY;
+          NS_ENSURE_TRUE(mBuffer, NS_ERROR_OUT_OF_MEMORY);
         }
 
         char* buffer = mBuffer;
@@ -1193,7 +1137,7 @@ NS_IMETHODIMP TokenStreamListener::OnDataAvailable(nsIRequest *aRequest, nsISupp
             if (totalCount >= (mBufferSize / 2)) {
                 PRUint32 newBufferSize = mBufferSize * 2;
                 char* newBuffer = new char[newBufferSize];
-                if (!newBuffer) return NS_ERROR_OUT_OF_MEMORY;
+                NS_ENSURE_TRUE(newBuffer, NS_ERROR_OUT_OF_MEMORY);
                 memcpy(newBuffer, mBuffer, mLeftOverCount);
                 delete[] mBuffer;
                 mBuffer = newBuffer;
@@ -1229,7 +1173,7 @@ NS_IMPL_ISUPPORTS5(nsBayesianFilter, nsIMsgFilterPlugin,
                    nsIObserver)
 
 nsBayesianFilter::nsBayesianFilter()
-    :   mTrainingDataDirty(PR_FALSE)
+    :   mTrainingDataDirty(false)
 {
     if (!BayesianFilterLogModule)
       BayesianFilterLogModule = PR_NewLogModule("BayesianFilter");
@@ -1286,11 +1230,10 @@ nsBayesianFilter::nsBayesianFilter()
 
 nsresult nsBayesianFilter::Init()
 {
-  nsresult rv;
   nsCOMPtr<nsIObserverService> observerService =
-           do_GetService("@mozilla.org/observer-service;1", &rv);
-  if (NS_SUCCEEDED(rv))
-    observerService->AddObserver(this, "profile-before-change", PR_TRUE);
+    mozilla::services::GetObserverService();
+  if (observerService)
+    observerService->AddObserver(this, "profile-before-change", true);
   return NS_OK;
 }
 
@@ -1302,7 +1245,7 @@ nsBayesianFilter::TimerCallback(nsITimer* aTimer, void* aClosure)
 
     nsBayesianFilter *filter = static_cast<nsBayesianFilter *>(aClosure);
     filter->mCorpus.writeTrainingData(filter->mMaximumTokenCount);
-    filter->mTrainingDataDirty = PR_FALSE;
+    filter->mTrainingDataDirty = false;
 }
 
 nsBayesianFilter::~nsBayesianFilter()
@@ -1427,6 +1370,7 @@ private:
 
 nsresult nsBayesianFilter::tokenizeMessage(const char* aMessageURI, nsIMsgWindow *aMsgWindow, TokenAnalyzer* aAnalyzer)
 {
+    NS_ENSURE_ARG_POINTER(aMessageURI);
 
     nsCOMPtr <nsIMsgMessageService> msgService;
     nsresult rv = GetMessageServiceFromURI(nsDependentCString(aMessageURI), getter_AddRefs(msgService));
@@ -1434,8 +1378,8 @@ nsresult nsBayesianFilter::tokenizeMessage(const char* aMessageURI, nsIMsgWindow
 
     aAnalyzer->setSource(aMessageURI);
     return msgService->StreamMessage(aMessageURI, aAnalyzer->mTokenListener,
-                                     aMsgWindow, nsnull, PR_TRUE /* convert data */,
-                                     NS_LITERAL_CSTRING("filter"), PR_FALSE, nsnull);
+                                     aMsgWindow, nsnull, true /* convert data */,
+                                     NS_LITERAL_CSTRING("filter"), false, nsnull);
 }
 
 // a TraitAnalysis is the per-token representation of the statistical
@@ -1800,9 +1744,9 @@ void nsBayesianFilter::classifyMessage(
         // see bug #194238
 
         if (listener && !mCorpus.getMessageCount(kGoodTrait))
-          isJunk = PR_TRUE;
+          isJunk = true;
         else if (listener && !mCorpus.getMessageCount(kJunkTrait))
-          isJunk = PR_FALSE;
+          isJunk = false;
 
         if (listener)
           listener->OnMessageClassified(messageURI, isJunk ?
@@ -1864,7 +1808,7 @@ NS_IMETHODIMP nsBayesianFilter::Shutdown()
 {
   if (mTrainingDataDirty)
     mCorpus.writeTrainingData(mMaximumTokenCount);
-  mTrainingDataDirty = PR_FALSE;
+  mTrainingDataDirty = false;
 
   return NS_OK;
 }
@@ -1873,7 +1817,7 @@ NS_IMETHODIMP nsBayesianFilter::Shutdown()
 NS_IMETHODIMP nsBayesianFilter::GetShouldDownloadAllHeaders(bool *aShouldDownloadAllHeaders)
 {
     // bayesian filters work on the whole msg body currently.
-    *aShouldDownloadAllHeaders = PR_FALSE;
+    *aShouldDownloadAllHeaders = false;
     return NS_OK;
 }
 
@@ -1881,11 +1825,9 @@ NS_IMETHODIMP nsBayesianFilter::GetShouldDownloadAllHeaders(bool *aShouldDownloa
 NS_IMETHODIMP nsBayesianFilter::ClassifyMessage(const char *aMessageURL, nsIMsgWindow *aMsgWindow, nsIJunkMailClassificationListener *aListener)
 {
     MessageClassifier* analyzer = new MessageClassifier(this, aListener, aMsgWindow, 1, &aMessageURL);
-    if (!analyzer)
-      return NS_ERROR_OUT_OF_MEMORY;
+    NS_ENSURE_TRUE(analyzer, NS_ERROR_OUT_OF_MEMORY);
     TokenStreamListener *tokenListener = new TokenStreamListener(analyzer);
-    if (!tokenListener)
-      return NS_ERROR_OUT_OF_MEMORY;
+    NS_ENSURE_TRUE(tokenListener, NS_ERROR_OUT_OF_MEMORY);
     analyzer->setTokenListener(tokenListener);
     return tokenizeMessage(aMessageURL, aMsgWindow, analyzer);
 }
@@ -1893,12 +1835,12 @@ NS_IMETHODIMP nsBayesianFilter::ClassifyMessage(const char *aMessageURL, nsIMsgW
 /* void classifyMessages (in unsigned long aCount, [array, size_is (aCount)] in string aMsgURLs, in nsIJunkMailClassificationListener aListener); */
 NS_IMETHODIMP nsBayesianFilter::ClassifyMessages(PRUint32 aCount, const char **aMsgURLs, nsIMsgWindow *aMsgWindow, nsIJunkMailClassificationListener *aListener)
 {
+    NS_ENSURE_ARG_POINTER(aMsgURLs);
+
     TokenAnalyzer* analyzer = new MessageClassifier(this, aListener, aMsgWindow, aCount, aMsgURLs);
-    if (!analyzer)
-      return NS_ERROR_OUT_OF_MEMORY;
+    NS_ENSURE_TRUE(analyzer, NS_ERROR_OUT_OF_MEMORY);
     TokenStreamListener *tokenListener = new TokenStreamListener(analyzer);
-    if (!tokenListener)
-      return NS_ERROR_OUT_OF_MEMORY;
+    NS_ENSURE_TRUE(tokenListener, NS_ERROR_OUT_OF_MEMORY);
     analyzer->setTokenListener(tokenListener);
     return tokenizeMessage(aMsgURLs[0], aMsgWindow, analyzer);
 }
@@ -2000,12 +1942,10 @@ NS_IMETHODIMP nsBayesianFilter::ClassifyTraitsInMessages(
 
   MessageClassifier* analyzer = new MessageClassifier(this, aJunkListener,
     aTraitListener, nsnull, proTraits, antiTraits, aMsgWindow, aCount, aMsgURIs);
-  if (!analyzer)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(analyzer, NS_ERROR_OUT_OF_MEMORY);
 
   TokenStreamListener *tokenListener = new TokenStreamListener(analyzer);
-  if (!tokenListener)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(tokenListener, NS_ERROR_OUT_OF_MEMORY);
 
   analyzer->setTokenListener(tokenListener);
   return tokenizeMessage(aMsgURIs[0], aMsgWindow, analyzer);
@@ -2063,11 +2003,11 @@ NS_IMETHODIMP nsBayesianFilter::SetMsgTraitClassification(
 
   MessageObserver* analyzer = new MessageObserver(this, oldTraits,
     newTraits, aJunkListener, aTraitListener);
-  if (!analyzer)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(analyzer, NS_ERROR_OUT_OF_MEMORY);
+
   TokenStreamListener *tokenListener = new TokenStreamListener(analyzer);
-  if (!tokenListener)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(tokenListener, NS_ERROR_OUT_OF_MEMORY);
+
   analyzer->setTokenListener(tokenListener);
   return tokenizeMessage(aMsgURI, aMsgWindow, analyzer);
 }
@@ -2105,7 +2045,7 @@ void nsBayesianFilter::observeMessage(
       {
         mCorpus.setMessageCount(trait, messageCount - 1);
         mCorpus.forgetTokens(tokens, trait, 1);
-        mTrainingDataDirty = PR_TRUE;
+        mTrainingDataDirty = true;
       }
     }
 
@@ -2117,7 +2057,7 @@ void nsBayesianFilter::observeMessage(
       PRUint32 trait = newClassifications.ElementAt(index);
       mCorpus.setMessageCount(trait, mCorpus.getMessageCount(trait) + 1);
       mCorpus.rememberTokens(tokens, trait, 1);
-      mTrainingDataDirty = PR_TRUE;
+      mTrainingDataDirty = true;
 
       if (aJunkListener)
       {
@@ -2197,12 +2137,10 @@ NS_IMETHODIMP nsBayesianFilter::SetMessageClassification(
 
   MessageObserver* analyzer = new MessageObserver(this, oldClassifications,
     newClassifications, aListener, nsnull);
-  if (!analyzer)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(analyzer, NS_ERROR_OUT_OF_MEMORY);
 
   TokenStreamListener *tokenListener = new TokenStreamListener(analyzer);
-  if (!tokenListener)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(tokenListener, NS_ERROR_OUT_OF_MEMORY);
 
   analyzer->setTokenListener(tokenListener);
   return tokenizeMessage(aMsgURL, aMsgWindow, analyzer);
@@ -2226,12 +2164,10 @@ NS_IMETHODIMP nsBayesianFilter::DetailMessage(const char *aMsgURI,
 
   MessageClassifier* analyzer = new MessageClassifier(this, nsnull,
     nsnull, aDetailListener, proTraits, antiTraits, aMsgWindow, 1, &aMsgURI);
-  if (!analyzer)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(analyzer, NS_ERROR_OUT_OF_MEMORY);
 
   TokenStreamListener *tokenListener = new TokenStreamListener(analyzer);
-  if (!tokenListener)
-    return NS_ERROR_OUT_OF_MEMORY;
+  NS_ENSURE_TRUE(tokenListener, NS_ERROR_OUT_OF_MEMORY);
 
   analyzer->setTokenListener(tokenListener);
   return tokenizeMessage(aMsgURI, aMsgWindow, analyzer);
@@ -2381,7 +2317,7 @@ bool CorpusStore::writeTokens(FILE* stream, bool shrink, PRUint32 aTraitId)
   }
 
   if (writeUInt32(stream, newTokenCount) != 1)
-    return PR_FALSE;
+    return false;
 
   if (newTokenCount > 0)
   {
@@ -2395,15 +2331,15 @@ bool CorpusStore::writeTokens(FILE* stream, bool shrink, PRUint32 aTraitId)
       if (!wordCount)
         continue; // Don't output zero count words
       if (writeUInt32(stream, wordCount) != 1)
-        return PR_FALSE;
+        return false;
       PRUint32 tokenLength = strlen(token->mWord);
       if (writeUInt32(stream, tokenLength) != 1)
-        return PR_FALSE;
+        return false;
       if (fwrite(token->mWord, tokenLength, 1, stream) != 1)
-        return PR_FALSE;
+        return false;
     }
   }
-  return PR_TRUE;
+  return true;
 }
 
 bool CorpusStore::readTokens(FILE* stream, PRInt64 fileSize,
@@ -2411,15 +2347,15 @@ bool CorpusStore::readTokens(FILE* stream, PRInt64 fileSize,
 {
     PRUint32 tokenCount;
     if (readUInt32(stream, &tokenCount) != 1)
-        return PR_FALSE;
+        return false;
 
     PRInt64 fpos = ftell(stream);
     if (fpos < 0)
-        return PR_FALSE;
+        return false;
 
     PRUint32 bufferSize = 4096;
     char* buffer = new char[bufferSize];
-    if (!buffer) return PR_FALSE;
+    if (!buffer) return false;
 
     for (PRUint32 i = 0; i < tokenCount; ++i) {
         PRUint32 count;
@@ -2431,17 +2367,17 @@ bool CorpusStore::readTokens(FILE* stream, PRInt64 fileSize,
         fpos += 8;
         if (fpos + size > fileSize) {
             delete[] buffer;
-            return PR_FALSE;
+            return false;
         }
         if (size >= bufferSize) {
             delete[] buffer;
             while (size >= bufferSize) {
                 bufferSize *= 2;
                 if (bufferSize == 0)
-                    return PR_FALSE;
+                    return false;
             }
             buffer = new char[bufferSize];
-            if (!buffer) return PR_FALSE;
+            if (!buffer) return false;
         }
         if (fread(buffer, size, 1, stream) != 1)
             break;
@@ -2455,7 +2391,7 @@ bool CorpusStore::readTokens(FILE* stream, PRInt64 fileSize,
 
     delete[] buffer;
 
-    return PR_TRUE;
+    return true;
 }
 
 nsresult CorpusStore::getTrainingFile(nsILocalFile ** aTrainingFile)
@@ -2528,7 +2464,7 @@ void CorpusStore::writeTrainingData(PRUint32 aMaximumTokenCount)
     NS_WARNING("failed to write training data.");
     fclose(stream);
     // delete the training data file, since it is potentially corrupt.
-    mTrainingFile->Remove(PR_FALSE);
+    mTrainingFile->Remove(false);
   }
   else
   {
@@ -2580,7 +2516,7 @@ void CorpusStore::writeTrainingData(PRUint32 aMaximumTokenCount)
   {
     NS_WARNING("failed to write trait data.");
     // delete the trait data file, since it is probably corrupt.
-    mTraitFile->Remove(PR_FALSE);
+    mTraitFile->Remove(false);
   }
 
   if (shrink)
@@ -2631,8 +2567,8 @@ void CorpusStore::readTrainingData()
         (memcmp(cookie, kMagicCookie, sizeof(cookie)) == 0) &&
         (readUInt32(stream, &goodMessageCount) == 1) &&
         (readUInt32(stream, &junkMessageCount) == 1) &&
-         readTokens(stream, fileSize, kGoodTrait, PR_TRUE) &&
-         readTokens(stream, fileSize, kJunkTrait, PR_TRUE))) {
+         readTokens(stream, fileSize, kGoodTrait, true) &&
+         readTokens(stream, fileSize, kJunkTrait, true))) {
       NS_WARNING("failed to read training data.");
       PR_LOG(BayesianFilterLogModule, PR_LOG_ERROR, ("failed to read training data."));
   }
@@ -2656,7 +2592,7 @@ void CorpusStore::readTrainingData()
   if (NS_FAILED(rv) || !exists)
     return;
 
-  rv = UpdateData(mTraitFile, PR_TRUE, 0, nsnull, nsnull);
+  rv = UpdateData(mTraitFile, true, 0, nsnull, nsnull);
 
   if (NS_FAILED(rv))
   {
@@ -2677,9 +2613,9 @@ nsresult CorpusStore::resetTrainingData()
     mMessageCounts[index] = 0;
 
   if (mTrainingFile)
-    mTrainingFile->Remove(PR_FALSE);
+    mTrainingFile->Remove(false);
   if (mTraitFile)
-    mTraitFile->Remove(PR_FALSE);
+    mTraitFile->Remove(false);
   return NS_OK;
 }
 
@@ -2875,8 +2811,6 @@ nsresult CorpusStore::ClearTrait(PRUint32 aTrait)
   // clear message counts
   setMessageCount(aTrait, 0);
 
-  // clear token counts
-  PRUint32 tokenCount = countTokens();
   TokenEnumeration tokens = getTokens();
   while (tokens.hasMoreTokens())
   {
