@@ -1,39 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Mailnews import code.
- *
- * The Initial Developer of the Original Code is 
- * Håkan Waara <hwaara@gmail.com>.
- * Portions created by the Initial Developer are Copyright (C) 2008
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #ifdef MOZ_LOGGING
 // sorry, this has to be before the pre-compiled header
@@ -48,8 +16,12 @@
 #include "nsIImportGeneric.h"
 #include "nsILocalFile.h"
 #include "nsIStringBundle.h"
+#include "nsIMsgFolder.h"
+#include "nsIMsgHdr.h"
+#include "nsIMsgPluggableStore.h"
 #include "nsNetUtil.h"
 #include "nsMsgUtils.h"
+#include "mozilla/Services.h"
 
 #include "nsEmlxHelperUtils.h"
 #include "nsAppleMailImport.h"
@@ -82,7 +54,8 @@ nsAppleMailImportModule::nsAppleMailImportModule()
 
   IMPORT_LOG0("nsAppleMailImportModule Created");
 
-  nsCOMPtr<nsIStringBundleService> bundleService(do_GetService(NS_STRINGBUNDLE_CONTRACTID));
+  nsCOMPtr<nsIStringBundleService> bundleService =
+    mozilla::services::GetStringBundleService();
   if (bundleService)
     bundleService->CreateBundle(APPLEMAIL_MSGS_URL, getter_AddRefs(mBundle));
 }
@@ -116,10 +89,10 @@ NS_IMETHODIMP nsAppleMailImportModule::GetSupports(char **aSupports)
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAppleMailImportModule::GetSupportsUpgrade(PRBool *aUpgrade)
+NS_IMETHODIMP nsAppleMailImportModule::GetSupportsUpgrade(bool *aUpgrade)
 {
   NS_ENSURE_ARG_POINTER(aUpgrade);
-  *aUpgrade = PR_FALSE;
+  *aUpgrade = false;
   return NS_OK;
 }
 
@@ -167,9 +140,9 @@ nsAppleMailImportMail::nsAppleMailImportMail() : mProgress(0), mCurDepth(0)
 
 nsresult nsAppleMailImportMail::Initialize()
 {
-  nsresult rv;
-  nsCOMPtr<nsIStringBundleService> bundleService(do_GetService(NS_STRINGBUNDLE_CONTRACTID, &rv));
-  NS_ENSURE_SUCCESS(rv, rv);
+  nsCOMPtr<nsIStringBundleService> bundleService =
+    mozilla::services::GetStringBundleService();
+  NS_ENSURE_TRUE(bundleService, NS_ERROR_UNEXPECTED);
 
   return bundleService->CreateBundle(APPLEMAIL_MSGS_URL, getter_AddRefs(mBundle));
 }
@@ -181,23 +154,23 @@ nsAppleMailImportMail::~nsAppleMailImportMail()
 
 NS_IMPL_THREADSAFE_ISUPPORTS1(nsAppleMailImportMail, nsIImportMail)
 
-NS_IMETHODIMP nsAppleMailImportMail::GetDefaultLocation(nsIFile **aLocation, PRBool *aFound, PRBool *aUserVerify)
+NS_IMETHODIMP nsAppleMailImportMail::GetDefaultLocation(nsIFile **aLocation, bool *aFound, bool *aUserVerify)
 {
   NS_ENSURE_ARG_POINTER(aFound);
   NS_ENSURE_ARG_POINTER(aLocation);
   NS_ENSURE_ARG_POINTER(aUserVerify);
 
   *aLocation = nsnull;
-  *aFound = PR_FALSE;
-  *aUserVerify = PR_TRUE;
+  *aFound = false;
+  *aUserVerify = true;
 
   // try to find current user's top-level Mail folder
   nsCOMPtr<nsILocalFile> mailFolder(do_CreateInstance(NS_LOCAL_FILE_CONTRACTID));
   if (mailFolder) {
     nsresult rv = mailFolder->InitWithNativePath(NS_LITERAL_CSTRING(DEFAULT_MAIL_FOLDER));
     if (NS_SUCCEEDED(rv)) {
-      *aFound = PR_TRUE;
-      *aUserVerify = PR_FALSE;
+      *aFound = true;
+      *aUserVerify = false;
       CallQueryInterface(mailFolder, aLocation);
     }
   }
@@ -214,7 +187,7 @@ NS_IMETHODIMP nsAppleMailImportMail::FindMailboxes(nsIFile *aMailboxFile, nsISup
 
   IMPORT_LOG0("FindMailboxes for Apple mail invoked");
 
-  PRBool exists = PR_FALSE;
+  bool exists = false;
   nsresult rv = aMailboxFile->Exists(&exists);
   if (NS_FAILED(rv) || !exists)
     return NS_ERROR_FAILURE;
@@ -268,7 +241,7 @@ void nsAppleMailImportMail::FindAccountMailDirs(nsIFile *aRoot, nsISupportsArray
   if (NS_FAILED(rv))
     return;
 
-  PRBool hasMore = PR_FALSE;
+  bool hasMore = false;
   while (NS_SUCCEEDED(directoryEnumerator->HasMoreElements(&hasMore)) && hasMore) {
 
     // get the next file entry
@@ -284,24 +257,24 @@ void nsAppleMailImportMail::FindAccountMailDirs(nsIFile *aRoot, nsISupportsArray
     }
 
     // make sure it's a directory
-    PRBool isDirectory = PR_FALSE;
+    bool isDirectory = false;
     currentEntry->IsDirectory(&isDirectory);
 
     if (isDirectory) {
       // now let's see if it's an account folder. if so, we want to traverse it for .mbox children
       nsAutoString folderName;
       currentEntry->GetLeafName(folderName);
-      PRBool isAccountFolder = PR_FALSE;
+      bool isAccountFolder = false;
 
       if (StringBeginsWith(folderName, NS_LITERAL_STRING("POP-"))) {
         // cut off "POP-" prefix so we get a nice folder name
         folderName.Cut(0, 4);
-        isAccountFolder = PR_TRUE;
+        isAccountFolder = true;
       }
       else if (StringBeginsWith(folderName, NS_LITERAL_STRING("IMAP-"))) {
         // cut off "IMAP-" prefix so we get a nice folder name
         folderName.Cut(0, 5);
-        isAccountFolder = PR_TRUE;
+        isAccountFolder = true;
       }
 
       if (isAccountFolder) {
@@ -367,7 +340,7 @@ nsresult nsAppleMailImportMail::AddMboxDir(nsILocalFile *aFolder, nsISupportsArr
       nsCOMPtr<nsISimpleEnumerator> dirEnumerator;
       messagesFolder->GetDirectoryEntries(getter_AddRefs(dirEnumerator));
       if (dirEnumerator) {
-        PRBool hasMore = PR_FALSE;
+        bool hasMore = false;
         while (NS_SUCCEEDED(dirEnumerator->HasMoreElements(&hasMore)) && hasMore) {
           nsCOMPtr<nsISupports> rawSupports;
           dirEnumerator->GetNext(getter_AddRefs(rawSupports));
@@ -376,7 +349,7 @@ nsresult nsAppleMailImportMail::AddMboxDir(nsILocalFile *aFolder, nsISupportsArr
 
           nsCOMPtr<nsILocalFile> file(do_QueryInterface(rawSupports));
           if (file) {
-            PRBool isFile = PR_FALSE;
+            bool isFile = false;
             file->IsFile(&isFile);
             if (isFile)
               numMessages++;
@@ -423,7 +396,7 @@ nsresult nsAppleMailImportMail::FindMboxDirs(nsILocalFile *aFolder, nsISupportsA
   NS_ENSURE_ARG_POINTER(aImportService);
 
   // make sure this is a directory.
-  PRBool isDir = PR_FALSE;
+  bool isDir = false;
   if (NS_FAILED(aFolder->IsDirectory(&isDir)) || !isDir)
     return NS_ERROR_FAILURE;
 
@@ -433,7 +406,7 @@ nsresult nsAppleMailImportMail::FindMboxDirs(nsILocalFile *aFolder, nsISupportsA
   if (NS_FAILED(rv) || !directoryEnumerator)
     return rv;
 
-  PRBool hasMore = PR_FALSE;
+  bool hasMore = false;
   while (NS_SUCCEEDED(directoryEnumerator->HasMoreElements(&hasMore)) && hasMore) {
 
     // get the next file entry
@@ -482,7 +455,7 @@ nsresult nsAppleMailImportMail::FindMboxDirs(nsILocalFile *aFolder, nsISupportsA
         continue;
 
       rv = siblingMailboxDir->InitWithPath(siblingMailboxDirPath);
-      PRBool reallyExists = PR_FALSE;
+      bool reallyExists = false;
       siblingMailboxDir->Exists(&reallyExists);
 
       if (NS_SUCCEEDED(rv) && reallyExists) {
@@ -499,8 +472,11 @@ nsresult nsAppleMailImportMail::FindMboxDirs(nsILocalFile *aFolder, nsISupportsA
   return NS_OK;
 }
 
-NS_IMETHODIMP nsAppleMailImportMail::ImportMailbox(nsIImportMailboxDescriptor *aMailbox, nsIFile *aDestination, 
-                                                   PRUnichar **aErrorLog, PRUnichar **aSuccessLog, PRBool *aFatalError)
+NS_IMETHODIMP
+nsAppleMailImportMail::ImportMailbox(nsIImportMailboxDescriptor *aMailbox,
+                                     nsIMsgFolder *aDstFolder,
+                                     PRUnichar **aErrorLog,
+                                     PRUnichar **aSuccessLog, bool *aFatalError)
 {
   nsAutoString errorLog, successLog;
 
@@ -554,15 +530,17 @@ NS_IMETHODIMP nsAppleMailImportMail::ImportMailbox(nsIImportMailboxDescriptor *a
     }
 
     // prepare an outstream to the destination file
-    nsCOMPtr<nsIOutputStream> outStream;
-    rv = MsgNewBufferedFileOutputStream(getter_AddRefs(outStream), aDestination);
-    if (!outStream || NS_FAILED(rv)) {
+    nsCOMPtr<nsIMsgPluggableStore> msgStore;
+    rv = aDstFolder->GetMsgStore(getter_AddRefs(msgStore));
+    if (!msgStore || NS_FAILED(rv)) {
       ReportStatus(APPLEMAILIMPORT_MAILBOX_CONVERTERROR, mailboxName, errorLog);
       SetLogs(successLog, errorLog, aSuccessLog, aErrorLog);
       return NS_ERROR_FAILURE;
     }
 
-    PRBool hasMore = PR_FALSE;
+    bool hasMore = false;
+    nsCOMPtr<nsIOutputStream> outStream;
+
     while (NS_SUCCEEDED(directoryEnumerator->HasMoreElements(&hasMore)) && hasMore) {
       // get the next file entry
       nsCOMPtr<nsILocalFile> currentEntry;
@@ -577,7 +555,7 @@ NS_IMETHODIMP nsAppleMailImportMail::ImportMailbox(nsIImportMailboxDescriptor *a
       }
 
       // make sure it's an .emlx file
-      PRBool isFile = PR_FALSE;
+      bool isFile = false;
       currentEntry->IsFile(&isFile);
       if (!isFile)
         continue;
@@ -587,12 +565,29 @@ NS_IMETHODIMP nsAppleMailImportMail::ImportMailbox(nsIImportMailboxDescriptor *a
       if (!StringEndsWith(leafName, NS_LITERAL_STRING(".emlx")))
         continue;
 
-      // add the data to the mbox stream
-      if (NS_SUCCEEDED(nsEmlxHelperUtils::AddEmlxMessageToStream(currentEntry, outStream)))
-        mProgress++;
-    }
-  }
+      nsCOMPtr<nsIMsgDBHdr> msgHdr;
+      bool reusable;
+      rv = msgStore->GetNewMsgOutputStream(aDstFolder, getter_AddRefs(msgHdr),
+                                           &reusable,
+                                           getter_AddRefs(outStream));
+      if (NS_FAILED(rv))
+        break;
 
+      // add the data to the mbox stream
+      if (NS_SUCCEEDED(nsEmlxHelperUtils::AddEmlxMessageToStream(currentEntry, outStream))) {
+        mProgress++;
+        msgStore->FinishNewMessage(outStream, msgHdr);
+      }
+      else {
+        msgStore->DiscardNewMessage(outStream, msgHdr);
+        break;
+      }
+      if (!reusable)
+        outStream->Close();
+    }
+    if (outStream)
+      outStream->Close();
+  }
   // just indicate that we're done, using the same number that we used to estimate
   // number of messages earlier.
   PRUint32 finalSize;
@@ -613,8 +608,10 @@ void nsAppleMailImportMail::ReportStatus(PRInt32 aErrorNum, nsString &aName, nsA
   const PRUnichar *fmt = { aName.get() };
   nsresult rv = mBundle->FormatStringFromID(aErrorNum, &fmt, 1, getter_Copies(outString));
   // write it out the stream
-  if (NS_SUCCEEDED(rv))
-    aStream.Append(outString + NS_LITERAL_STRING("\n"));
+  if (NS_SUCCEEDED(rv)) {
+    aStream.Append(outString);
+    aStream.Append(PRUnichar('\n'));
+  }
 }
 
 void nsAppleMailImportMail::SetLogs(const nsAString &aSuccess, const nsAString &aError, PRUnichar **aOutSuccess, PRUnichar **aOutError)
