@@ -1,40 +1,7 @@
 /* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
-* Version: MPL 1.1/GPL 2.0/LGPL 2.1
-*
-* The contents of this file are subject to the Mozilla Public License Version
-* 1.1 (the "License"); you may not use this file except in compliance with
-* the License. You may obtain a copy of the License at
-* http://www.mozilla.org/MPL/
-*
-* Software distributed under the License is distributed on an "AS IS" basis,
-* WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-* for the specific language governing rights and limitations under the
-* License.
-*
-* The Original Code is qualcomm.com code.
-*
-* The Initial Developer of the Original Code is
-* QUALCOMM, Inc.
-* Portions created by the Initial Developer are Copyright (C) 2007
-* the Initial Developer. All Rights Reserved.
-*
-* Contributor(s):
-*   Author: Geoffrey C. Wenger (gwenger@qualcomm.com)
-*
-* Alternatively, the contents of this file may be used under the terms of
-* either the GNU General Public License Version 2 or later (the "GPL"), or
-* the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
-* in which case the provisions of the GPL or the LGPL are applicable instead
-* of those above. If you wish to allow use of your version of this file only
-* under the terms of either the GPL or the LGPL, and not to allow others to
-* use your version of this file under the terms of the MPL, indicate your
-* decision by deleting the provisions above and replace them with the notice
-* and other provisions required by the GPL or the LGPL. If you do not delete
-* the provisions above, a recipient may use your version of this file under
-* the terms of any one of the MPL, the GPL or the LGPL.
-*
-* ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+* License, v. 2.0. If a copy of the MPL was not distributed with this
+* file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 
 #include "nsEudoraEditor.h"
@@ -78,7 +45,7 @@ static PRUint32 EudoraHashString(const char* pszStr)
     }
   }
 
-  return (ulSum + 1);
+  return ulSum + 1;
 }
 
 
@@ -105,7 +72,7 @@ nsresult nsEudoraEditor::GetEmbeddedObjects(nsISupportsArray ** aNodeList)
   }
 
   // Create array in m_EmbeddedObjectList
-  nsresult rv = NS_NewISupportsArray( getter_AddRefs(m_EmbeddedObjectList) );
+  nsresult rv = NS_NewISupportsArray(getter_AddRefs(m_EmbeddedObjectList));
   NS_ENSURE_SUCCESS(rv, rv);
 
   // Return m_EmbeddedObjectList in aNodeList and increment ref count - caller
@@ -145,15 +112,17 @@ nsresult nsEudoraEditor::GetEmbeddedObjects(nsISupportsArray ** aNodeList)
     PRInt32   startEmbeddedContentLine = startLastClosingTag;
     PRInt32   lenEmbeddedContentTag = strlen(sEudoraEmbeddedContentLines[i]);
 
-    while ( (startEmbeddedContentLine = m_body.Find(sEudoraEmbeddedContentLines[i], PR_TRUE, startEmbeddedContentLine+1)) != kNotFound )
+    while ((startEmbeddedContentLine = m_body.Find(sEudoraEmbeddedContentLines[i],
+                                                   true,
+                                                   startEmbeddedContentLine+1)) != kNotFound)
     {
       // Found this translation of "Embedded Content" - remember that so that we don't
       // bother looking for any other translations.
-      foundEmbeddedContentLines = PR_TRUE;
+      foundEmbeddedContentLines = true;
 
       // Extract the file name from the embedded content line
       PRInt32   startFileName = startEmbeddedContentLine + lenEmbeddedContentTag;
-      PRInt32   endFileName = m_body.Find(":", PR_FALSE, startFileName);
+      PRInt32   endFileName = m_body.Find(":", false, startFileName);
 
       // Create the file spec for the embedded image
       embeddedFolderSpec->Clone(getter_AddRefs(embeddedImageSpec));
@@ -162,25 +131,25 @@ nsresult nsEudoraEditor::GetEmbeddedObjects(nsISupportsArray ** aNodeList)
       // Verify that the embedded image spec exists and is a file
       bool      isFile = false;
       bool      exists = false;
-      if ( NS_FAILED(embeddedImageSpec->Exists( &exists)) || NS_FAILED(embeddedImageSpec->IsFile(&isFile)) )
+      if (NS_FAILED(embeddedImageSpec->Exists(&exists)) || NS_FAILED(embeddedImageSpec->IsFile(&isFile)))
         continue;
       if (!exists || !isFile)
         continue;
 
       // Extract CID hash from the embedded content line
       PRInt32     cidHashValue;
-      PRInt32     startCIDHash = m_body.Find(",", PR_FALSE, endFileName);
+      PRInt32     startCIDHash = m_body.Find(",", false, endFileName);
       if (startCIDHash != kNotFound)
       {
         startCIDHash++;
-        PRInt32   endCIDHash = m_body.Find(",", PR_FALSE, startCIDHash);
+        PRInt32   endCIDHash = m_body.Find(",", false, startCIDHash);
 
         if (endCIDHash != kNotFound)
         {
           nsString    cidHash;
           cidHash.Assign(Substring(m_body, startCIDHash, endCIDHash - startCIDHash));
 
-          if ( !cidHash.IsEmpty() )
+          if (!cidHash.IsEmpty())
           {
             // Convert CID hash string to numeric value
             nsresult aErrorCode;
@@ -203,13 +172,12 @@ nsresult nsEudoraEditor::GetEmbeddedObjects(nsISupportsArray ** aNodeList)
       nsEudoraHTMLImageElement *image =
         new nsEudoraHTMLImageElement(srcUrl, cid);
 
-      nsCOMPtr<nsIDOMHTMLImageElement>   imageNode;
-      image->QueryInterface( NS_GET_IID(nsIDOMHTMLImageElement), getter_AddRefs(imageNode) );
+      nsCOMPtr<nsIDOMHTMLImageElement> imageNode(do_QueryInterface(image));
 
       // Append the embedded image node to the list
       (*aNodeList)->AppendElement(imageNode);
 
-      PRInt32   endEmbeddedContentLine = m_body.Find("\r\n", PR_TRUE, startEmbeddedContentLine+1);
+      PRInt32   endEmbeddedContentLine = m_body.Find("\r\n", true, startEmbeddedContentLine+1);
       if (endEmbeddedContentLine != kNotFound)
       {
         // We recognized the "Embedded Content" line correctly and found the associated image.
@@ -235,7 +203,7 @@ bool nsEudoraEditor::GetEmbeddedImageCID(PRUint32 aCIDHash, const nsAString & aO
   PRInt32   startImageTag = 0;
   PRInt32   closeImageTag = 0;
 
-  while ( (startImageTag = m_body.Find("<img", true, closeImageTag)) != kNotFound )
+  while ((startImageTag = m_body.Find("<img", true, closeImageTag)) != kNotFound)
   {
     closeImageTag = m_body.Find(">", false, startImageTag);
 
@@ -245,14 +213,14 @@ bool nsEudoraEditor::GetEmbeddedImageCID(PRUint32 aCIDHash, const nsAString & aO
 
     // Find the source attribute and make sure it's for our image tag
     PRInt32   startSrcValue = m_body.Find("src", true, startImageTag);
-    if ( (startSrcValue == kNotFound) || (startSrcValue > closeImageTag) )
+    if ((startSrcValue == kNotFound) || (startSrcValue > closeImageTag))
       continue;
 
     // Move past the src
     startSrcValue += 3;
 
     // Move past any whitespace
-    while ( isspace(m_body.CharAt(startSrcValue)) )
+    while (isspace(m_body.CharAt(startSrcValue)))
       ++startSrcValue;
 
     // We should find an = now
@@ -263,12 +231,12 @@ bool nsEudoraEditor::GetEmbeddedImageCID(PRUint32 aCIDHash, const nsAString & aO
     ++startSrcValue;
 
     // Move past any whitespace
-    while ( isspace(m_body.CharAt(startSrcValue)) )
+    while (isspace(m_body.CharAt(startSrcValue)))
       ++startSrcValue;
 
     // Get the quote char and verify that it's valid
     char    quoteChar = static_cast <char> (m_body.CharAt(startSrcValue));
-    if ( (quoteChar != '"') && (quoteChar != '\'') )
+    if ((quoteChar != '"') && (quoteChar != '\''))
       continue;
 
     // Move past the quote
@@ -289,7 +257,7 @@ bool nsEudoraEditor::GetEmbeddedImageCID(PRUint32 aCIDHash, const nsAString & aO
       // Remove "cid:" from the start
       aCID.Cut(0, 4);
 
-      PRUint32  hashValue = EudoraHashString( NS_LossyConvertUTF16toASCII(aCID).get() );
+      PRUint32  hashValue = EudoraHashString(NS_LossyConvertUTF16toASCII(aCID).get());
       foundMatch = (hashValue == aCIDHash);
     }
     else
@@ -309,7 +277,7 @@ bool nsEudoraEditor::HasEmbeddedContent()
 
   for (PRInt32 i = 0; *sEudoraEmbeddedContentLines[i] != '\0'; i++)
   {
-    bHasEmbeddedContent = (m_body.Find(sEudoraEmbeddedContentLines[i], PR_TRUE, 0) != kNotFound);
+    bHasEmbeddedContent = (m_body.Find(sEudoraEmbeddedContentLines[i], true, 0) != kNotFound);
 
     if (bHasEmbeddedContent)
       break;
@@ -464,7 +432,7 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::HasChildNodes(bool *_retval)
 
 
 // nsIDOMNode cloneNode (in boolean deep)
-NS_IMETHODIMP nsEudoraHTMLImageElement::CloneNode(bool deep, nsIDOMNode **_retval)
+NS_IMETHODIMP nsEudoraHTMLImageElement::CloneNode(bool deep, PRUint8 aOptionalArgc, nsIDOMNode **_retval)
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -1247,3 +1215,20 @@ NS_IMETHODIMP nsEudoraHTMLImageElement::MozMatchesSelector(const nsAString &aSel
 {
   return NS_ERROR_NOT_IMPLEMENTED;
 }
+
+NS_IMETHODIMP nsEudoraHTMLImageElement::MozRequestPointerLock()
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+NS_IMETHODIMP
+nsEudoraHTMLImageElement::GetX(PRInt32* aX)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
+
+NS_IMETHODIMP
+nsEudoraHTMLImageElement::GetY(PRInt32* aY)
+{
+  return NS_ERROR_NOT_IMPLEMENTED;
+}
