@@ -1,40 +1,7 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1998
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Pierre Phaneuf <pp@ludusdesign.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either of the GNU General Public License Version 2 or later (the "GPL"),
- * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 
 /*
@@ -100,9 +67,10 @@ public:
   /* nsISupportsArray FindMailboxes (in nsIFile location); */
   NS_IMETHOD FindMailboxes(nsIFile *location, nsISupportsArray **_retval);
 
-  /* void ImportMailbox (in nsIImportMailboxDescriptor source, in nsIFile destination, out boolean fatalError); */
-  NS_IMETHOD ImportMailbox(nsIImportMailboxDescriptor *source, nsIFile *destination,
-                PRUnichar **pErrorLog, PRUnichar **pSuccessLog, bool *fatalError);
+  NS_IMETHOD ImportMailbox(nsIImportMailboxDescriptor *source,
+                           nsIMsgFolder *dstFolder,
+                           PRUnichar **pErrorLog, PRUnichar **pSuccessLog,
+                           bool *fatalError);
 
   /* unsigned long GetImportProgress (); */
   NS_IMETHOD GetImportProgress(PRUint32 *_retval);
@@ -110,10 +78,10 @@ public:
     NS_IMETHOD TranslateFolderName(const nsAString & aFolderName, nsAString & _retval);
 
 public:
-  static void ReportSuccess( nsString& name, PRInt32 count, nsString *pStream);
-  static void ReportError( PRInt32 errorNum, nsString& name, nsString *pStream);
-  static void AddLinebreak( nsString *pStream);
-  static void SetLogs( nsString& success, nsString& error, PRUnichar **pError, PRUnichar **pSuccess);
+  static void ReportSuccess(nsString& name, PRInt32 count, nsString *pStream);
+  static void ReportError(PRInt32 errorNum, nsString& name, nsString *pStream);
+  static void AddLinebreak(nsString *pStream);
+  static void SetLogs(nsString& success, nsString& error, PRUnichar **pError, PRUnichar **pSuccess);
 
 private:
   PRUint32 m_bytesDone;
@@ -133,19 +101,19 @@ public:
 
     // nsIImportAddressBooks interface
 
-  NS_IMETHOD GetSupportsMultiple(bool *_retval) { *_retval = false; return( NS_OK);}
+  NS_IMETHOD GetSupportsMultiple(bool *_retval) { *_retval = false; return NS_OK;}
 
   NS_IMETHOD GetAutoFind(PRUnichar **description, bool *_retval);
 
-  NS_IMETHOD GetNeedsFieldMap(nsIFile *pLoc, bool *_retval) { *_retval = false; return( NS_OK);}
+  NS_IMETHOD GetNeedsFieldMap(nsIFile *pLoc, bool *_retval) { *_retval = false; return NS_OK;}
 
   NS_IMETHOD GetDefaultLocation(nsIFile **location, bool *found, bool *userVerify)
-    { return( NS_ERROR_FAILURE);}
+    { return NS_ERROR_FAILURE;}
 
   NS_IMETHOD FindAddressBooks(nsIFile *location, nsISupportsArray **_retval);
 
   NS_IMETHOD InitFieldMap(nsIImportFieldMap *fieldMap)
-    { return( NS_ERROR_FAILURE); }
+    { return NS_ERROR_FAILURE; }
 
   NS_IMETHOD ImportAddressBook(nsIImportABDescriptor *source,
                                nsIAddrDatabase *destination,
@@ -157,13 +125,13 @@ public:
 
   NS_IMETHOD GetImportProgress(PRUint32 *_retval);
 
-  NS_IMETHOD GetSampleData( PRInt32 index, bool *pFound, PRUnichar **pStr)
-    { return( NS_ERROR_FAILURE);}
+  NS_IMETHOD GetSampleData(PRInt32 index, bool *pFound, PRUnichar **pStr)
+    { return NS_ERROR_FAILURE;}
 
-  NS_IMETHOD SetSampleLocation( nsIFile *) { return( NS_OK); }
+  NS_IMETHOD SetSampleLocation(nsIFile *) { return NS_OK; }
 
 private:
-  static void ReportSuccess( nsString& name, nsString *pStream);
+  static void ReportSuccess(nsString& name, nsString *pStream);
 
 private:
   CWAB * m_pWab;
@@ -180,121 +148,120 @@ nsOEImport::nsOEImport()
   // Init logging module.
   if (!OELOGMODULE)
     OELOGMODULE = PR_NewLogModule("IMPORT");
-  IMPORT_LOG0( "nsOEImport Module Created\n");
+  IMPORT_LOG0("nsOEImport Module Created\n");
   nsOEStringBundle::GetStringBundle();
 }
 
 
 nsOEImport::~nsOEImport()
 {
-  IMPORT_LOG0( "nsOEImport Module Deleted\n");
+  IMPORT_LOG0("nsOEImport Module Deleted\n");
 }
 
 NS_IMPL_ISUPPORTS1(nsOEImport, nsIImportModule)
 
-NS_IMETHODIMP nsOEImport::GetName( PRUnichar **name)
+NS_IMETHODIMP nsOEImport::GetName(PRUnichar **name)
 {
   NS_ENSURE_ARG_POINTER(name);
 
-  *name = nsOEStringBundle::GetStringByID( OEIMPORT_NAME);
+  *name = nsOEStringBundle::GetStringByID(OEIMPORT_NAME);
 
     return NS_OK;
 }
 
-NS_IMETHODIMP nsOEImport::GetDescription( PRUnichar **name)
+NS_IMETHODIMP nsOEImport::GetDescription(PRUnichar **name)
 {
   NS_ENSURE_ARG_POINTER(name);
 
-  *name = nsOEStringBundle::GetStringByID( OEIMPORT_DESCRIPTION);
+  *name = nsOEStringBundle::GetStringByID(OEIMPORT_DESCRIPTION);
   return NS_OK;
 }
 
-NS_IMETHODIMP nsOEImport::GetSupports( char **supports)
+NS_IMETHODIMP nsOEImport::GetSupports(char **supports)
 {
   NS_PRECONDITION(supports != nsnull, "null ptr");
   if (! supports)
       return NS_ERROR_NULL_POINTER;
 
-  *supports = strdup( kOESupportsString);
-  return( NS_OK);
+  *supports = strdup(kOESupportsString);
+  return NS_OK;
 }
 
 
-NS_IMETHODIMP nsOEImport::GetSupportsUpgrade( bool *pUpgrade)
+NS_IMETHODIMP nsOEImport::GetSupportsUpgrade(bool *pUpgrade)
 {
   NS_PRECONDITION(pUpgrade != nsnull, "null ptr");
   if (! pUpgrade)
     return NS_ERROR_NULL_POINTER;
 
-  *pUpgrade = PR_TRUE;
-  return( NS_OK);
+  *pUpgrade = true;
+  return NS_OK;
 }
 
-NS_IMETHODIMP nsOEImport::GetImportInterface( const char *pImportType, nsISupports **ppInterface)
+NS_IMETHODIMP nsOEImport::GetImportInterface(const char *pImportType, nsISupports **ppInterface)
 {
   NS_ENSURE_ARG_POINTER(pImportType);
   NS_ENSURE_ARG_POINTER(ppInterface);
 
   *ppInterface = nsnull;
   nsresult rv;
-  if (!strcmp( pImportType, "mail")) {
+  if (!strcmp(pImportType, "mail")) {
     // create the nsIImportMail interface and return it!
     nsIImportMail *  pMail = nsnull;
     nsIImportGeneric *pGeneric = nsnull;
-    rv = ImportOEMailImpl::Create( &pMail);
-    if (NS_SUCCEEDED( rv)) {
+    rv = ImportOEMailImpl::Create(&pMail);
+    if (NS_SUCCEEDED(rv)) {
       nsCOMPtr<nsIImportService> impSvc(do_GetService(NS_IMPORTSERVICE_CONTRACTID, &rv));
-      if (NS_SUCCEEDED( rv)) {
-        rv = impSvc->CreateNewGenericMail( &pGeneric);
-        if (NS_SUCCEEDED( rv)) {
-          pGeneric->SetData( "mailInterface", pMail);
+      if (NS_SUCCEEDED(rv)) {
+        rv = impSvc->CreateNewGenericMail(&pGeneric);
+        if (NS_SUCCEEDED(rv)) {
+          pGeneric->SetData("mailInterface", pMail);
           nsString name;
-          nsOEStringBundle::GetStringByID( OEIMPORT_NAME, name);
+          nsOEStringBundle::GetStringByID(OEIMPORT_NAME, name);
           nsCOMPtr<nsISupportsString> nameString (do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, &rv));
           if (NS_SUCCEEDED(rv)) {
             nameString->SetData(name);
-            pGeneric->SetData( "name", nameString);
-            rv = pGeneric->QueryInterface( kISupportsIID, (void **)ppInterface);
+            pGeneric->SetData("name", nameString);
+            rv = pGeneric->QueryInterface(kISupportsIID, (void **)ppInterface);
           }
         }
       }
     }
-    NS_IF_RELEASE( pMail);
-    NS_IF_RELEASE( pGeneric);
-    return( rv);
+    NS_IF_RELEASE(pMail);
+    NS_IF_RELEASE(pGeneric);
+    return rv;
   }
 
-  if (!strcmp( pImportType, "addressbook")) {
+  if (!strcmp(pImportType, "addressbook")) {
     // create the nsIImportMail interface and return it!
     nsIImportAddressBooks * pAddress = nsnull;
     nsIImportGeneric * pGeneric = nsnull;
-    rv = ImportOEAddressImpl::Create( &pAddress);
-    if (NS_SUCCEEDED( rv)) {
+    rv = ImportOEAddressImpl::Create(&pAddress);
+    if (NS_SUCCEEDED(rv)) {
       nsCOMPtr<nsIImportService> impSvc(do_GetService(NS_IMPORTSERVICE_CONTRACTID, &rv));
-      if (NS_SUCCEEDED( rv)) {
-        rv = impSvc->CreateNewGenericAddressBooks( &pGeneric);
-        if (NS_SUCCEEDED( rv)) {
-          pGeneric->SetData( "addressInterface", pAddress);
-          rv = pGeneric->QueryInterface( kISupportsIID, (void **)ppInterface);
+      if (NS_SUCCEEDED(rv)) {
+        rv = impSvc->CreateNewGenericAddressBooks(&pGeneric);
+        if (NS_SUCCEEDED(rv)) {
+          pGeneric->SetData("addressInterface", pAddress);
+          rv = pGeneric->QueryInterface(kISupportsIID, (void **)ppInterface);
         }
       }
     }
-    NS_IF_RELEASE( pAddress);
-    NS_IF_RELEASE( pGeneric);
-    return( rv);
+    NS_IF_RELEASE(pAddress);
+    NS_IF_RELEASE(pGeneric);
+    return rv;
   }
 
-  if (!strcmp( pImportType, "settings")) {
+  if (!strcmp(pImportType, "settings")) {
     nsIImportSettings *pSettings = nsnull;
-    rv = nsOESettings::Create( &pSettings);
-    if (NS_SUCCEEDED( rv)) {
-      pSettings->QueryInterface( kISupportsIID, (void **)ppInterface);
-    }
-    NS_IF_RELEASE( pSettings);
-    return( rv);
+    rv = nsOESettings::Create(&pSettings);
+    if (NS_SUCCEEDED(rv))
+      pSettings->QueryInterface(kISupportsIID, (void **)ppInterface);
+    NS_IF_RELEASE(pSettings);
+    return rv;
   }
 
-  return( NS_ERROR_NOT_AVAILABLE);
+  return NS_ERROR_NOT_AVAILABLE;
 }
 
 /////////////////////////////////////////////////////////////////////////////////
@@ -332,7 +299,7 @@ NS_IMETHODIMP ImportOEMailImpl::TranslateFolderName(const nsAString & aFolderNam
   return NS_OK;
 }
 
-NS_IMETHODIMP ImportOEMailImpl::GetDefaultLocation( nsIFile **ppLoc, bool *found, bool *userVerify)
+NS_IMETHODIMP ImportOEMailImpl::GetDefaultLocation(nsIFile **ppLoc, bool *found, bool *userVerify)
 {
   NS_PRECONDITION(ppLoc != nsnull, "null ptr");
   NS_PRECONDITION(found != nsnull, "null ptr");
@@ -347,19 +314,19 @@ NS_IMETHODIMP ImportOEMailImpl::GetDefaultLocation( nsIFile **ppLoc, bool *found
     return rv;
 
   if (nsOEScanBoxes::FindMail(file)) {
-    *found = PR_TRUE;
+    *found = true;
     NS_IF_ADDREF(*ppLoc = file);
   }
   else {
-    *found = PR_FALSE;
+    *found = false;
     *ppLoc = nsnull;
   }
-  *userVerify = PR_TRUE;
-  return( NS_OK);
+  *userVerify = true;
+  return NS_OK;
 }
 
 
-NS_IMETHODIMP ImportOEMailImpl::FindMailboxes( nsIFile *pLoc, nsISupportsArray **ppArray)
+NS_IMETHODIMP ImportOEMailImpl::FindMailboxes(nsIFile *pLoc, nsISupportsArray **ppArray)
 {
     NS_PRECONDITION(pLoc != nsnull, "null ptr");
     NS_PRECONDITION(ppArray != nsnull, "null ptr");
@@ -367,52 +334,52 @@ NS_IMETHODIMP ImportOEMailImpl::FindMailboxes( nsIFile *pLoc, nsISupportsArray *
         return NS_ERROR_NULL_POINTER;
 
   bool exists = false;
-  nsresult rv = pLoc->Exists( &exists);
-  if (NS_FAILED( rv) || !exists)
-    return( NS_ERROR_FAILURE);
+  nsresult rv = pLoc->Exists(&exists);
+  if (NS_FAILED(rv) || !exists)
+    return NS_ERROR_FAILURE;
 
   nsOEScanBoxes  scan;
 
-  if (!scan.GetMailboxes( pLoc, ppArray))
+  if (!scan.GetMailboxes(pLoc, ppArray))
     *ppArray = nsnull;
 
-  return( NS_OK);
+  return NS_OK;
 }
 
-void ImportOEMailImpl::AddLinebreak( nsString *pStream)
+void ImportOEMailImpl::AddLinebreak(nsString *pStream)
 {
   if (pStream)
-    pStream->Append( PRUnichar('\n'));
+    pStream->Append(PRUnichar('\n'));
 }
 
-void ImportOEMailImpl::ReportSuccess( nsString& name, PRInt32 count, nsString *pStream)
+void ImportOEMailImpl::ReportSuccess(nsString& name, PRInt32 count, nsString *pStream)
 {
   if (!pStream)
     return;
   // load the success string
-  PRUnichar *pFmt = nsOEStringBundle::GetStringByID( OEIMPORT_MAILBOX_SUCCESS);
-  PRUnichar *pText = nsTextFormatter::smprintf( pFmt, name.get(), count);
-  pStream->Append( pText);
-  nsTextFormatter::smprintf_free( pText);
-  nsOEStringBundle::FreeString( pFmt);
-  AddLinebreak( pStream);
+  PRUnichar *pFmt = nsOEStringBundle::GetStringByID(OEIMPORT_MAILBOX_SUCCESS);
+  PRUnichar *pText = nsTextFormatter::smprintf(pFmt, name.get(), count);
+  pStream->Append(pText);
+  nsTextFormatter::smprintf_free(pText);
+  nsOEStringBundle::FreeString(pFmt);
+  AddLinebreak(pStream);
 }
 
-void ImportOEMailImpl::ReportError( PRInt32 errorNum, nsString& name, nsString *pStream)
+void ImportOEMailImpl::ReportError(PRInt32 errorNum, nsString& name, nsString *pStream)
 {
   if (!pStream)
     return;
   // load the error string
   PRUnichar *pFmt = nsOEStringBundle::GetStringByID(errorNum);
-  PRUnichar *pText = nsTextFormatter::smprintf( pFmt, name.get());
-  pStream->Append( pText);
-  nsTextFormatter::smprintf_free( pText);
-  nsOEStringBundle::FreeString( pFmt);
-  AddLinebreak( pStream);
+  PRUnichar *pText = nsTextFormatter::smprintf(pFmt, name.get());
+  pStream->Append(pText);
+  nsTextFormatter::smprintf_free(pText);
+  nsOEStringBundle::FreeString(pFmt);
+  AddLinebreak(pStream);
 }
 
 
-void ImportOEMailImpl::SetLogs( nsString& success, nsString& error, PRUnichar **pError, PRUnichar **pSuccess)
+void ImportOEMailImpl::SetLogs(nsString& success, nsString& error, PRUnichar **pError, PRUnichar **pSuccess)
 {
   if (pError)
     *pError = ToNewUnicode(error);
@@ -421,81 +388,71 @@ void ImportOEMailImpl::SetLogs( nsString& success, nsString& error, PRUnichar **
 }
 
 NS_IMETHODIMP ImportOEMailImpl::ImportMailbox(nsIImportMailboxDescriptor *pSource,
-                                              nsIFile *pDestination,
+                                              nsIMsgFolder *dstFolder,
                                               PRUnichar **pErrorLog,
                                               PRUnichar **pSuccessLog,
                                               bool *fatalError)
 {
-  NS_PRECONDITION(pSource != nsnull, "null ptr");
-  NS_PRECONDITION(pDestination != nsnull, "null ptr");
-  NS_PRECONDITION(fatalError != nsnull, "null ptr");
+  NS_ENSURE_ARG_POINTER(pSource);
+  NS_ENSURE_ARG_POINTER(dstFolder);
+  NS_ENSURE_ARG_POINTER(fatalError);
 
   nsString success;
   nsString error;
-  if (!pSource || !pDestination || !fatalError) {
-    nsOEStringBundle::GetStringByID( OEIMPORT_MAILBOX_BADPARAM, error);
-    if (fatalError)
-      *fatalError = PR_TRUE;
-    SetLogs( success, error, pErrorLog, pSuccessLog);
-    return NS_ERROR_NULL_POINTER;
-  }
-
   bool abort = false;
   nsString name;
   nsString pName;
-  if (NS_SUCCEEDED( pSource->GetDisplayName( getter_Copies(pName))))
+  if (NS_SUCCEEDED(pSource->GetDisplayName(getter_Copies(pName))))
     name = pName;
 
   PRUint32 mailSize = 0;
-  pSource->GetSize( &mailSize);
+  pSource->GetSize(&mailSize);
   if (mailSize == 0) {
-    ReportSuccess( name, 0, &success);
-    SetLogs( success, error, pErrorLog, pSuccessLog);
-    return( NS_OK);
+    ReportSuccess(name, 0, &success);
+    SetLogs(success, error, pErrorLog, pSuccessLog);
+    return NS_OK;
   }
 
   nsCOMPtr <nsILocalFile> inFile;
-  if (NS_FAILED( pSource->GetFile(getter_AddRefs(inFile)))) {
-    ReportError( OEIMPORT_MAILBOX_BADSOURCEFILE, name, &error);
-    SetLogs( success, error, pErrorLog, pSuccessLog);
-    return( NS_ERROR_FAILURE);
+  if (NS_FAILED(pSource->GetFile(getter_AddRefs(inFile)))) {
+    ReportError(OEIMPORT_MAILBOX_BADSOURCEFILE, name, &error);
+    SetLogs(success, error, pErrorLog, pSuccessLog);
+    return NS_ERROR_FAILURE;
   }
 
   nsCString pPath;
   inFile->GetNativePath(pPath);
-  IMPORT_LOG1( "Importing Outlook Express mailbox: %s\n", pPath.get());
+  IMPORT_LOG1("Importing Outlook Express mailbox: %s\n", pPath.get());
 
   m_bytesDone = 0;
   PRUint32 msgCount = 0;
   nsresult rv;
-  if (nsOE5File::IsLocalMailFile( inFile)) {
-    IMPORT_LOG1( "Importing OE5 mailbox: %s!\n", NS_LossyConvertUTF16toASCII(name.get()));
-    rv = nsOE5File::ImportMailbox( &m_bytesDone, &abort, name, inFile, pDestination, &msgCount);
+  if (nsOE5File::IsLocalMailFile(inFile)) {
+    IMPORT_LOG1("Importing OE5 mailbox: %s!\n", NS_LossyConvertUTF16toASCII(name.get()));
+    rv = nsOE5File::ImportMailbox( &m_bytesDone, &abort, name, inFile, dstFolder, &msgCount);
   }
   else {
-    if (CImportMailbox::ImportMailbox( &m_bytesDone, &abort, name, inFile, pDestination, &msgCount))
-      rv = NS_OK;
+    if (CImportMailbox::ImportMailbox( &m_bytesDone, &abort, name, inFile, dstFolder, &msgCount))
+       rv = NS_OK;
     else
       rv = NS_ERROR_FAILURE;
   }
 
-  if (NS_SUCCEEDED( rv)) {
-    ReportSuccess( name, msgCount, &success);
-  }
-  else {
-    ReportError( OEIMPORT_MAILBOX_CONVERTERROR, name, &error);
-  }
+  if (NS_SUCCEEDED(rv))
+    ReportSuccess(name, msgCount, &success);
+  else
+    ReportError(OEIMPORT_MAILBOX_CONVERTERROR, name, &error);
 
-  SetLogs( success, error, pErrorLog, pSuccessLog);
+  SetLogs(success, error, pErrorLog, pSuccessLog);
 
-  return( rv);
+  return rv;
 }
 
-NS_IMETHODIMP ImportOEMailImpl::GetImportProgress( PRUint32 *pDoneSoFar)
+NS_IMETHODIMP ImportOEMailImpl::GetImportProgress(PRUint32 *pDoneSoFar)
 {
   NS_ENSURE_ARG_POINTER(pDoneSoFar);
   *pDoneSoFar = m_bytesDone;
-  return( NS_OK);
+  return NS_OK;
 }
 
 nsresult ImportOEAddressImpl::Create(nsIImportAddressBooks** aImport)
@@ -529,11 +486,11 @@ NS_IMETHODIMP ImportOEAddressImpl::GetAutoFind(PRUnichar **description, bool *_r
   if (! description || !_retval)
     return NS_ERROR_NULL_POINTER;
 
-  *_retval = PR_TRUE;
+  *_retval = true;
   nsString str;
   str.Append(nsOEStringBundle::GetStringByID(OEIMPORT_AUTOFIND));
   *description = ToNewUnicode(str);
-  return( NS_OK);
+  return NS_OK;
 }
 
 
@@ -544,45 +501,45 @@ NS_IMETHODIMP ImportOEAddressImpl::FindAddressBooks(nsIFile *location, nsISuppor
   if (!_retval)
     return NS_ERROR_NULL_POINTER;
 
-  nsresult rv = NS_NewISupportsArray( _retval);
-  if (NS_FAILED( rv))
-    return( rv);
+  nsresult rv = NS_NewISupportsArray(_retval);
+  if (NS_FAILED(rv))
+    return rv;
 
   // Make sure we can load up the windows address book...
   rv = NS_ERROR_FAILURE;
 
   if (m_pWab)
     delete m_pWab;
-  m_pWab = new CWAB( nsnull);
+  m_pWab = new CWAB(nsnull);
 
   nsIImportABDescriptor * pID;
   nsISupports * pInterface;
   nsString str;
-  str.Append(nsOEStringBundle::GetStringByID( OEIMPORT_DEFAULT_NAME));
+  str.Append(nsOEStringBundle::GetStringByID(OEIMPORT_DEFAULT_NAME));
 
   if (m_pWab->Loaded()) {
     // create a new nsIImportABDescriptor and add it to the array
     nsCOMPtr<nsIImportService> impSvc(do_GetService(NS_IMPORTSERVICE_CONTRACTID, &rv));
-    if (NS_SUCCEEDED( rv)) {
-      rv = impSvc->CreateNewABDescriptor( &pID);
-      if (NS_SUCCEEDED( rv)) {
-        pID->SetIdentifier( 0x4F453334);
-        pID->SetRef( 1);
-        pID->SetSize( 100);
+    if (NS_SUCCEEDED(rv)) {
+      rv = impSvc->CreateNewABDescriptor(&pID);
+      if (NS_SUCCEEDED(rv)) {
+        pID->SetIdentifier(0x4F453334);
+        pID->SetRef(1);
+        pID->SetSize(100);
         pID->SetPreferredName(str);
-        rv = pID->QueryInterface( kISupportsIID, (void **) &pInterface);
-        (*_retval)->AppendElement( pInterface);
+        rv = pID->QueryInterface(kISupportsIID, (void **) &pInterface);
+        (*_retval)->AppendElement(pInterface);
         pInterface->Release();
         pID->Release();
       }
     }
   }
 
-  if (NS_FAILED( rv)) {
+  if (NS_FAILED(rv)) {
     delete m_pWab;
     m_pWab = nsnull;
   }
-  return( NS_OK);
+  return NS_OK;
 }
 
 
@@ -604,40 +561,35 @@ NS_IMETHODIMP ImportOEAddressImpl::ImportAddressBook(nsIImportABDescriptor *sour
 
   // we assume it is our one and only address book.
   if (!m_pWab) {
-    IMPORT_LOG0( "Wab not loaded in ImportAddressBook call\n");
-    return( NS_ERROR_FAILURE);
+    IMPORT_LOG0("Wab not loaded in ImportAddressBook call\n");
+    return NS_ERROR_FAILURE;
   }
 
-  IMPORT_LOG0( "IMPORTING OUTLOOK EXPRESS ADDRESS BOOK\n");
+  IMPORT_LOG0("IMPORTING OUTLOOK EXPRESS ADDRESS BOOK\n");
 
   nsString success;
   nsString error;
   if (!source || !destination || !fatalError)
   {
-    nsOEStringBundle::GetStringByID( OEIMPORT_ADDRESS_BADPARAM, error);
+    nsOEStringBundle::GetStringByID(OEIMPORT_ADDRESS_BADPARAM, error);
     if (fatalError)
-      *fatalError = PR_TRUE;
-    ImportOEMailImpl::SetLogs( success, error, errorLog, successLog);
+      *fatalError = true;
+    ImportOEMailImpl::SetLogs(success, error, errorLog, successLog);
     return NS_ERROR_NULL_POINTER;
   }
 
   m_doneSoFar = 0;
-  nsOEAddressIterator * pIter = new nsOEAddressIterator( m_pWab, destination);
-  HRESULT hr = m_pWab->IterateWABContents( pIter, &m_doneSoFar);
+  nsOEAddressIterator * pIter = new nsOEAddressIterator(m_pWab, destination);
+  HRESULT hr = m_pWab->IterateWABContents(pIter, &m_doneSoFar);
   delete pIter;
 
   nsString name;
-  if (SUCCEEDED(hr))
-  {
-    if (NS_SUCCEEDED(source->GetPreferredName(name)))
-    {
-      ReportSuccess( name, &success);
-    }
-  }
+  if (SUCCEEDED(hr) && NS_SUCCEEDED(source->GetPreferredName(name)))
+    ReportSuccess(name, &success);
   else
-    ImportOEMailImpl::ReportError( OEIMPORT_ADDRESS_CONVERTERROR, name, &error);
+    ImportOEMailImpl::ReportError(OEIMPORT_ADDRESS_CONVERTERROR, name, &error);
 
-  ImportOEMailImpl::SetLogs( success, error, errorLog, successLog);
+  ImportOEMailImpl::SetLogs(success, error, errorLog, successLog);
 
   nsresult rv = destination->Commit(nsAddrDBCommitType::kLargeCommit);
   return rv;
@@ -651,18 +603,18 @@ NS_IMETHODIMP ImportOEAddressImpl::GetImportProgress(PRUint32 *_retval)
     return NS_ERROR_NULL_POINTER;
 
   *_retval = (PRUint32) m_doneSoFar;
-  return( NS_OK);
+  return NS_OK;
 }
 
-void ImportOEAddressImpl::ReportSuccess( nsString& name, nsString *pStream)
+void ImportOEAddressImpl::ReportSuccess(nsString& name, nsString *pStream)
 {
   if (!pStream)
     return;
   // load the success string
-  PRUnichar *pFmt = nsOEStringBundle::GetStringByID( OEIMPORT_ADDRESS_SUCCESS);
-  PRUnichar *pText = nsTextFormatter::smprintf( pFmt, name.get());
-  pStream->Append( pText);
-  nsTextFormatter::smprintf_free( pText);
-  nsOEStringBundle::FreeString( pFmt);
-  ImportOEMailImpl::AddLinebreak( pStream);
+  PRUnichar *pFmt = nsOEStringBundle::GetStringByID(OEIMPORT_ADDRESS_SUCCESS);
+  PRUnichar *pText = nsTextFormatter::smprintf(pFmt, name.get());
+  pStream->Append(pText);
+  nsTextFormatter::smprintf_free(pText);
+  nsOEStringBundle::FreeString(pFmt);
+  ImportOEMailImpl::AddLinebreak(pStream);
 }
