@@ -1,41 +1,6 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is Mozilla
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corp.
- * Portions created by the Initial Developer are Copyright (C) 2001
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *                 Krishna Mohan Khandrika (kkhandrika@netscape.com)
- *                 Srilatha Moturi (srilatha@netscape.com)
- *                 Rajiv Dayal (rdayal@netscape.com)
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+/* This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 #define MAPI_STARTUP_ARG       "/MAPIStartUp"
 
@@ -69,9 +34,7 @@
 #include "nsIMsgCompose.h"
 #include "nsMsgCompCID.h"
 #include "nsIMsgSend.h"
-#include "nsIProxyObjectManager.h"
 #include "nsIMsgComposeService.h"
-#include "nsProxiedService.h"
 #include "nsDirectoryServiceDefs.h"
 #include "nsIDirectoryService.h"
 #include "nsMsgI18N.h"
@@ -80,7 +43,9 @@
 #include "msgMapiSupport.h"
 #include "msgMapiMain.h"
 #include "nsThreadUtils.h"
+#include "nsMsgUtils.h"
 #include "nsNetUtil.h"
+#include "mozilla/Services.h"
 
 #include "nsEmbedCID.h"
 
@@ -109,7 +74,7 @@ public:
                            nsIFile *returnFile) {
         PR_CEnterMonitor(this);
         PR_CNotifyAll(this);
-        m_done = PR_TRUE;
+        m_done = true;
         PR_CExitMonitor(this);
         return NS_OK ;
     }
@@ -125,14 +90,14 @@ public:
 
     static nsresult CreateMAPISendListener( nsIMsgSendListener **ppListener);
 
-    PRBool IsDone() { return m_done ; }
+    bool IsDone() { return m_done ; }
 
 protected :
     nsMAPISendListener() {
-        m_done = PR_FALSE;
+        m_done = false;
     }
 
-    PRBool          m_done;
+    bool            m_done;
 };
 
 
@@ -150,7 +115,7 @@ nsresult nsMAPISendListener::CreateMAPISendListener( nsIMsgSendListener **ppList
     return NS_OK;
 }
 
-PRBool nsMapiHook::isMapiService = PR_FALSE;
+bool nsMapiHook::isMapiService = false;
 
 void nsMapiHook::CleanUp()
 {
@@ -158,33 +123,34 @@ void nsMapiHook::CleanUp()
     // to cleanup mapi related stuff inside mozilla code.
 }
 
-PRBool nsMapiHook::DisplayLoginDialog(PRBool aLogin, PRUnichar **aUsername,
+bool nsMapiHook::DisplayLoginDialog(bool aLogin, PRUnichar **aUsername,
                       PRUnichar **aPassword)
 {
   nsresult rv;
-  PRBool btnResult = PR_FALSE;
+  bool btnResult = false;
 
   nsCOMPtr<nsIPromptService> dlgService(do_GetService(NS_PROMPTSERVICE_CONTRACTID, &rv));
   if (NS_SUCCEEDED(rv) && dlgService)
   {
-    nsCOMPtr<nsIStringBundleService> bundleService(do_GetService(NS_STRINGBUNDLE_CONTRACTID, &rv));
-    if (NS_FAILED(rv) || !bundleService) return PR_FALSE;
+    nsCOMPtr<nsIStringBundleService> bundleService =
+      mozilla::services::GetStringBundleService();
+    if (!bundleService) return false;
 
     nsCOMPtr<nsIStringBundle> bundle;
     rv = bundleService->CreateBundle(MAPI_PROPERTIES_CHROME, getter_AddRefs(bundle));
-    if (NS_FAILED(rv) || !bundle) return PR_FALSE;
+    if (NS_FAILED(rv) || !bundle) return false;
 
     nsCOMPtr<nsIStringBundle> brandBundle;
     rv = bundleService->CreateBundle(
                     "chrome://branding/locale/brand.properties",
                     getter_AddRefs(brandBundle));
-    if (NS_FAILED(rv)) return PR_FALSE;
+    if (NS_FAILED(rv)) return false;
 
     nsString brandName;
     rv = brandBundle->GetStringFromName(
                        NS_LITERAL_STRING("brandFullName").get(),
                        getter_Copies(brandName));
-    if (NS_FAILED(rv)) return PR_FALSE;
+    if (NS_FAILED(rv)) return false;
 
     nsString loginTitle;
     const PRUnichar *brandStrings[] = { brandName.get() };
@@ -192,16 +158,16 @@ PRBool nsMapiHook::DisplayLoginDialog(PRBool aLogin, PRUnichar **aUsername,
     const PRUnichar *dTitlePropertyTag = loginTitlePropertyTag.get();
     rv = bundle->FormatStringFromName(dTitlePropertyTag, brandStrings, 1,
                                       getter_Copies(loginTitle));
-    if (NS_FAILED(rv)) return PR_FALSE;
+    if (NS_FAILED(rv)) return false;
 
     if (aLogin)
     {
       nsString loginText;
       rv = bundle->GetStringFromName(NS_LITERAL_STRING("loginTextwithName").get(),
                                      getter_Copies(loginText));
-      if (NS_FAILED(rv) || loginText.IsEmpty()) return PR_FALSE;
+      if (NS_FAILED(rv) || loginText.IsEmpty()) return false;
 
-      PRBool dummyValue = PR_FALSE;
+      bool dummyValue = false;
       rv = dlgService->PromptUsernameAndPassword(nsnull, loginTitle.get(),
                                                  loginText.get(), aUsername, aPassword,
                                                  nsnull, &dummyValue, &btnResult);
@@ -216,9 +182,9 @@ PRBool nsMapiHook::DisplayLoginDialog(PRBool aLogin, PRUnichar **aUsername,
       const PRUnichar *dpropertyTag = loginTextPropertyTag.get();
       rv = bundle->FormatStringFromName(dpropertyTag, userNameStrings, 1,
                                         getter_Copies(loginText));
-      if (NS_FAILED(rv)) return PR_FALSE;
+      if (NS_FAILED(rv)) return false;
 
-      PRBool dummyValue = PR_FALSE;
+      bool dummyValue = false;
       rv = dlgService->PromptPassword(nsnull, loginTitle.get(), loginText.get(),
                                       aPassword, nsnull, &dummyValue, &btnResult);
     }
@@ -227,18 +193,18 @@ PRBool nsMapiHook::DisplayLoginDialog(PRBool aLogin, PRUnichar **aUsername,
   return btnResult;
 }
 
-PRBool nsMapiHook::VerifyUserName(const nsString& aUsername, nsCString& aIdKey)
+bool nsMapiHook::VerifyUserName(const nsString& aUsername, nsCString& aIdKey)
 {
   nsresult rv;
 
   if (aUsername.IsEmpty())
-    return PR_FALSE;
+    return false;
 
   nsCOMPtr<nsIMsgAccountManager> accountManager(do_GetService(NS_MSGACCOUNTMANAGER_CONTRACTID, &rv));
-  if (NS_FAILED(rv)) return PR_FALSE;
+  if (NS_FAILED(rv)) return false;
   nsCOMPtr<nsISupportsArray> identities;
   rv = accountManager->GetAllIdentities(getter_AddRefs(identities));
-  if (NS_FAILED(rv)) return PR_FALSE;
+  if (NS_FAILED(rv)) return false;
   PRUint32 numIndentities;
   identities->Count(&numIndentities);
 
@@ -265,52 +231,53 @@ PRBool nsMapiHook::VerifyUserName(const nsString& aUsername, nsCString& aIdKey)
     }
   }
 
-  return PR_FALSE;
+  return false;
 }
 
-PRBool
+bool
 nsMapiHook::IsBlindSendAllowed()
 {
-  PRBool enabled = PR_FALSE;
-  PRBool warn = PR_TRUE;
+  bool enabled = false;
+  bool warn = true;
   nsCOMPtr<nsIPrefBranch> prefBranch = do_GetService(NS_PREFSERVICE_CONTRACTID);
   if (prefBranch) {
       prefBranch->GetBoolPref(PREF_MAPI_WARN_PRIOR_TO_BLIND_SEND, &warn);
       prefBranch->GetBoolPref(PREF_MAPI_BLIND_SEND_ENABLED, &enabled);
   }
   if (!enabled)
-      return PR_FALSE;
+      return false;
 
   if (!warn)
-      return PR_TRUE; // Everything is okay.
+      return true; // Everything is okay.
 
   nsresult rv;
-  nsCOMPtr<nsIStringBundleService> bundleService(do_GetService(NS_STRINGBUNDLE_CONTRACTID, &rv));
-  if (NS_FAILED(rv) || !bundleService) return PR_FALSE;
+  nsCOMPtr<nsIStringBundleService> bundleService =
+    mozilla::services::GetStringBundleService();
+  if (!bundleService) return false;
 
   nsCOMPtr<nsIStringBundle> bundle;
   rv = bundleService->CreateBundle(MAPI_PROPERTIES_CHROME, getter_AddRefs(bundle));
-  if (NS_FAILED(rv) || !bundle) return PR_FALSE;
+  if (NS_FAILED(rv) || !bundle) return false;
 
   nsString warningMsg;
   rv = bundle->GetStringFromName(NS_LITERAL_STRING("mapiBlindSendWarning").get(),
                                       getter_Copies(warningMsg));
-  if (NS_FAILED(rv)) return PR_FALSE;
+  if (NS_FAILED(rv)) return false;
 
   nsString dontShowAgainMessage;
   rv = bundle->GetStringFromName(NS_LITERAL_STRING("mapiBlindSendDontShowAgain").get(),
                                       getter_Copies(dontShowAgainMessage));
-  if (NS_FAILED(rv)) return PR_FALSE;
+  if (NS_FAILED(rv)) return false;
 
   nsCOMPtr<nsIPromptService> dlgService(do_GetService(NS_PROMPTSERVICE_CONTRACTID, &rv));
-  if (NS_FAILED(rv) || !dlgService) return PR_FALSE;
+  if (NS_FAILED(rv) || !dlgService) return false;
 
-  PRBool continueToWarn = PR_TRUE;
-  PRBool okayToContinue = PR_FALSE;
+  bool continueToWarn = true;
+  bool okayToContinue = false;
   dlgService->ConfirmCheck(nsnull, nsnull, warningMsg.get(), dontShowAgainMessage.get(), &continueToWarn, &okayToContinue);
 
   if (!continueToWarn && okayToContinue && prefBranch)
-    prefBranch->SetBoolPref(PREF_MAPI_WARN_PRIOR_TO_BLIND_SEND, PR_FALSE);
+    prefBranch->SetBoolPref(PREF_MAPI_WARN_PRIOR_TO_BLIND_SEND, false);
 
   return okayToContinue;
 }
@@ -362,7 +329,7 @@ nsresult nsMapiHook::BlindSendMail (unsigned long aSession, nsIMsgCompFields * a
   if (NS_FAILED(rv) || (!pMsgComposeParams) ) return rv ;
 
   // populate the compose params
-  PRBool forcePlainText;
+  bool forcePlainText;
   aCompFields->GetForcePlainText(&forcePlainText);
   pMsgComposeParams->SetType(nsIMsgCompType::New);
   pMsgComposeParams->SetFormat(forcePlainText ? nsIMsgCompFormat::PlainText : nsIMsgCompFormat::HTML);
@@ -380,7 +347,9 @@ nsresult nsMapiHook::BlindSendMail (unsigned long aSession, nsIMsgCompFields * a
   rv = pMsgCompose->Initialize(pMsgComposeParams, hiddenWindow, nsnull);
   if (NS_FAILED(rv)) return rv ;
 
-  return pMsgCompose->SendMsg(nsIMsgSend::nsMsgDeliverNow, pMsgId, nsnull, nsnull, nsnull) ;
+  // If we're in offline mode, we'll need to queue it for later. No point in trying to send it.
+  return pMsgCompose->SendMsg(WeAreOffline() ? nsIMsgSend::nsMsgQueueForLater : nsIMsgSend::nsMsgDeliverNow,
+			      pMsgId, nsnull, nsnull, nsnull);
   if (NS_FAILED(rv)) return rv ;
 
   // assign to interface pointer from nsCOMPtr to facilitate typecast below
@@ -460,7 +429,7 @@ nsresult nsMapiHook::PopulateCompFields(lpnsMapiMessage aMessage,
     aCompFields->SetSubject(NS_ConvertASCIItoUTF16(aMessage->lpszSubject));
 
   // handle attachments as File URL
-  rv = HandleAttachments (aCompFields, aMessage->nFileCount, aMessage->lpFiles, PR_TRUE) ;
+  rv = HandleAttachments (aCompFields, aMessage->nFileCount, aMessage->lpFiles, true) ;
   if (NS_FAILED(rv)) return rv ;
 
   // set body
@@ -472,7 +441,7 @@ nsresult nsMapiHook::PopulateCompFields(lpnsMapiMessage aMessage,
         Body.AppendLiteral(CRLF);
 
       if (Body.Find("<html>") == kNotFound)
-        aCompFields->SetForcePlainText(PR_TRUE);
+        aCompFields->SetForcePlainText(true);
 
       rv = aCompFields->SetBody(Body) ;
   }
@@ -494,7 +463,7 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, PRInt32
 
     for (int i=0 ; i < aFileCount ; i++)
     {
-        PRBool bTempFile = PR_FALSE ;
+        bool bTempFile = false ;
         if (aFiles[i].lpszPathName)
         {
             // check if attachment exists
@@ -503,7 +472,7 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, PRInt32
             else
                 pFile->InitWithNativePath (nsDependentCString((const char*)aFiles[i].lpszPathName));
 
-            PRBool bExist ;
+            bool bExist ;
             rv = pFile->Exists(&bExist) ;
             PR_LOG(MAPI, PR_LOG_DEBUG, ("nsMapiHook::HandleAttachments: filename: %s path: %s exists = %s \n", (const char*)aFiles[i].lpszFileName, (const char*)aFiles[i].lpszPathName, bExist ? "true" : "false"));
             if (NS_FAILED(rv) || (!bExist) ) return NS_ERROR_FILE_TARGET_DOES_NOT_EXIST ;
@@ -560,7 +529,7 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, PRInt32
             {
               rv = pTempFile->CreateUnique(nsIFile::NORMAL_FILE_TYPE, 0777);
               NS_ENSURE_SUCCESS(rv, rv);
-              pTempFile->Remove(PR_FALSE); // remove so we can copy over it.
+              pTempFile->Remove(false); // remove so we can copy over it.
               pTempFile->GetLeafName(leafName);
             }
             // copy the file to its new location and file name
@@ -570,7 +539,7 @@ nsresult nsMapiHook::HandleAttachments (nsIMsgCompFields * aCompFields, PRInt32
             pFile->Append(leafName);
 
             // create MsgCompose attachment object
-            attachment->SetTemporary(PR_TRUE); // this one is a temp file so set the flag for MsgCompose
+            attachment->SetTemporary(true); // this one is a temp file so set the flag for MsgCompose
 
             // now set the attachment object
             nsCAutoString pURL ;
@@ -664,7 +633,7 @@ nsresult nsMapiHook::PopulateCompFieldsWithConversion(lpnsMapiMessage aMessage,
   }
 
   // handle attachments as File URL
-  rv = HandleAttachments (aCompFields, aMessage->nFileCount, aMessage->lpFiles, PR_FALSE) ;
+  rv = HandleAttachments (aCompFields, aMessage->nFileCount, aMessage->lpFiles, false) ;
   if (NS_FAILED(rv)) return rv ;
 
   // set body
@@ -679,7 +648,7 @@ nsresult nsMapiHook::PopulateCompFieldsWithConversion(lpnsMapiMessage aMessage,
       Body.AppendLiteral(CRLF);
 
     if (Body.Find("<html>") == kNotFound)
-      aCompFields->SetForcePlainText(PR_TRUE);
+      aCompFields->SetForcePlainText(true);
 
     rv = aCompFields->SetBody(Body) ;
   }
@@ -701,7 +670,7 @@ nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompField
   nsAutoString strDelimChars ;
   nsString strFilePaths;
   nsresult rv = NS_OK ;
-  PRBool bExist ;
+  bool bExist ;
 
   if (aFlags & MAPI_UNICODE)
   {
@@ -810,7 +779,7 @@ nsresult nsMapiHook::PopulateCompFieldsForSendDocs(nsIMsgCompFields * aCompField
       pTempDir->Append(fileNameNative);
 
       // this one is a temp file so set the flag for MsgCompose
-      attachment->SetTemporary(PR_TRUE);
+      attachment->SetTemporary(true);
 
       // now set the attachment object
       nsCAutoString pURL;
@@ -847,7 +816,7 @@ nsresult nsMapiHook::ShowComposerWindow (unsigned long aSession, nsIMsgCompField
     nsCOMPtr<nsIMsgComposeParams> pMsgComposeParams (do_CreateInstance(NS_MSGCOMPOSEPARAMS_CONTRACTID, &rv));
     if (NS_FAILED(rv) || (!pMsgComposeParams) ) return rv ;
 
-    PRBool forcePlainText;
+    bool forcePlainText;
     aCompFields->GetForcePlainText(&forcePlainText);
     pMsgComposeParams->SetFormat(forcePlainText ? nsIMsgCompFormat::Default : nsIMsgCompFormat::HTML);
     // populate the compose params
